/****************************************************************************
** Meta object code from reading C++ file 'netmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../net-view/operation/netmanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'netmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3dde7network10NetManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::NetManager::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network10NetManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::NetManager",
        "request",
        "",
        "CmdType",
        "cmd",
        "id",
        "QVariantMap",
        "param",
        "airplaneModeChanged",
        "enabled",
        "networkNotify",
        "inAppName",
        "replacesId",
        "appIcon",
        "summary",
        "body",
        "actions",
        "hints",
        "expireTimeout",
        "languageChange",
        "locale",
        "toControlCenter",
        "netCheckAvailableChanged",
        "netCheckAvailable",
        "primaryConnectionTypeChanged",
        "ConnectionType",
        "type",
        "gotoControlCenter",
        "gotoCheckNet",
        "CheckPasswordValid",
        "key",
        "password",
        "root",
        "NetItem*",
        "EnabledDevice",
        "DisabledDevice",
        "RequestScan",
        "Disconnect",
        "Connect",
        "ConnectOrInfo",
        "UserCancelRequest",
        "GoToControlCenter",
        "GoToSecurityTools",
        "RequestPassword",
        "CheckInput",
        "InputValid",
        "CloseInput",
        "InputError",
        "ToggleExpand",
        "ConnectInfo",
        "SetConnectInfo",
        "DeleteConnect",
        "ImportConnect",
        "ImportError",
        "ExportConnect",
        "ShowPage"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'request'
        QtMocHelpers::SignalData<void(enum CmdType, const QString &, const QVariantMap &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Signal 'airplaneModeChanged'
        QtMocHelpers::SignalData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Signal 'networkNotify'
        QtMocHelpers::SignalData<void(const QString &, int, const QString &, const QString &, const QString &, const QStringList &, const QVariantMap &, int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 }, { QMetaType::Int, 12 }, { QMetaType::QString, 13 }, { QMetaType::QString, 14 },
            { QMetaType::QString, 15 }, { QMetaType::QStringList, 16 }, { 0x80000000 | 6, 17 }, { QMetaType::Int, 18 },
        }}),
        // Signal 'languageChange'
        QtMocHelpers::SignalData<void(const QString &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Signal 'toControlCenter'
        QtMocHelpers::SignalData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'netCheckAvailableChanged'
        QtMocHelpers::SignalData<void(const bool &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 23 },
        }}),
        // Signal 'primaryConnectionTypeChanged'
        QtMocHelpers::SignalData<void(enum ConnectionType)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Slot 'gotoControlCenter'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'gotoCheckNet'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'netCheckAvailable'
        QtMocHelpers::SlotData<bool()>(23, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'CheckPasswordValid'
        QtMocHelpers::MethodData<bool(const QString &, const QString &)>(29, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 30 }, { QMetaType::QString, 31 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'root'
        QtMocHelpers::PropertyData<NetItem*>(32, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'CmdType'
        QtMocHelpers::EnumData<enum CmdType>(3, 3, QMC::EnumFlags{}).add({
            {   34, CmdType::EnabledDevice },
            {   35, CmdType::DisabledDevice },
            {   36, CmdType::RequestScan },
            {   37, CmdType::Disconnect },
            {   38, CmdType::Connect },
            {   39, CmdType::ConnectOrInfo },
            {   40, CmdType::UserCancelRequest },
            {   41, CmdType::GoToControlCenter },
            {   42, CmdType::GoToSecurityTools },
            {   43, CmdType::RequestPassword },
            {   44, CmdType::CheckInput },
            {   45, CmdType::InputValid },
            {   46, CmdType::CloseInput },
            {   47, CmdType::InputError },
            {   48, CmdType::ToggleExpand },
            {   49, CmdType::ConnectInfo },
            {   50, CmdType::SetConnectInfo },
            {   51, CmdType::DeleteConnect },
            {   52, CmdType::ImportConnect },
            {   53, CmdType::ImportError },
            {   54, CmdType::ExportConnect },
            {   55, CmdType::ShowPage },
        }),
    };
    return QtMocHelpers::metaObjectData<NetManager, qt_meta_tag_ZN3dde7network10NetManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::NetManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network10NetManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network10NetManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network10NetManagerE_t>.metaTypes,
    nullptr
} };

void dde::network::NetManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NetManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->request((*reinterpret_cast<std::add_pointer_t<enum CmdType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[3]))); break;
        case 1: _t->airplaneModeChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->networkNotify((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[8]))); break;
        case 3: _t->languageChange((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->toControlCenter(); break;
        case 5: _t->netCheckAvailableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->primaryConnectionTypeChanged((*reinterpret_cast<std::add_pointer_t<enum ConnectionType>>(_a[1]))); break;
        case 7: _t->gotoControlCenter(); break;
        case 8: _t->gotoCheckNet(); break;
        case 9: { bool _r = _t->netCheckAvailable();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: { bool _r = _t->CheckPasswordValid((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NetManager::*)(CmdType , const QString & , const QVariantMap & )>(_a, &NetManager::request, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetManager::*)(bool )>(_a, &NetManager::airplaneModeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetManager::*)(const QString & , int , const QString & , const QString & , const QString & , const QStringList & , const QVariantMap & , int )>(_a, &NetManager::networkNotify, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetManager::*)(const QString & )>(_a, &NetManager::languageChange, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetManager::*)()>(_a, &NetManager::toControlCenter, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetManager::*)(const bool & )>(_a, &NetManager::netCheckAvailableChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetManager::*)(ConnectionType )>(_a, &NetManager::primaryConnectionTypeChanged, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<NetItem**>(_v) = _t->root(); break;
        default: break;
        }
    }
}

const QMetaObject *dde::network::NetManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::NetManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network10NetManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dde::network::NetManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void dde::network::NetManager::request(CmdType _t1, const QString & _t2, const QVariantMap & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void dde::network::NetManager::airplaneModeChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void dde::network::NetManager::networkNotify(const QString & _t1, int _t2, const QString & _t3, const QString & _t4, const QString & _t5, const QStringList & _t6, const QVariantMap & _t7, int _t8)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3, _t4, _t5, _t6, _t7, _t8);
}

// SIGNAL 3
void dde::network::NetManager::languageChange(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void dde::network::NetManager::toControlCenter()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void dde::network::NetManager::netCheckAvailableChanged(const bool & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void dde::network::NetManager::primaryConnectionTypeChanged(ConnectionType _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
