/****************************************************************************
** Meta object code from reading C++ file 'netitem.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../net-view/operation/netitem.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'netitem.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3dde7network7NetItemE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::NetItem::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network7NetItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::NetItem",
        "idChanged",
        "",
        "newID",
        "oldID",
        "nameChanged",
        "name",
        "dataChanged",
        "childAboutToBeAdded",
        "const NetItem*",
        "parent",
        "pos",
        "childAdded",
        "child",
        "childAboutToBeRemoved",
        "childRemoved",
        "childrenChanged",
        "getChild",
        "NetItem*",
        "childPos",
        "getChildIndex",
        "getChildrenNumber",
        "getChildren",
        "getIndex",
        "getParent",
        "id",
        "itemType",
        "NetType::NetItemType",
        "children",
        "QList<NetItem*>"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'idChanged'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Signal 'dataChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'childAboutToBeAdded'
        QtMocHelpers::SignalData<void(const NetItem *, int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { QMetaType::Int, 11 },
        }}),
        // Signal 'childAdded'
        QtMocHelpers::SignalData<void(const NetItem *)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 13 },
        }}),
        // Signal 'childAboutToBeRemoved'
        QtMocHelpers::SignalData<void(const NetItem *, int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { QMetaType::Int, 11 },
        }}),
        // Signal 'childRemoved'
        QtMocHelpers::SignalData<void(const NetItem *)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 13 },
        }}),
        // Signal 'childrenChanged'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'getChild'
        QtMocHelpers::SlotData<NetItem *(int) const>(17, 2, QMC::AccessPublic, 0x80000000 | 18, {{
            { QMetaType::Int, 19 },
        }}),
        // Slot 'getChildIndex'
        QtMocHelpers::SlotData<int(const NetItem *) const>(20, 2, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 9, 13 },
        }}),
        // Slot 'getChildrenNumber'
        QtMocHelpers::SlotData<int() const>(21, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'getChildren'
        QtMocHelpers::SlotData<void() const>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'getIndex'
        QtMocHelpers::SlotData<int() const>(23, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'getParent'
        QtMocHelpers::SlotData<NetItem *() const>(24, 2, QMC::AccessPublic, 0x80000000 | 18),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'id'
        QtMocHelpers::PropertyData<QString>(25, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'itemType'
        QtMocHelpers::PropertyData<NetType::NetItemType>(26, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'children'
        QtMocHelpers::PropertyData<QList<NetItem*>>(28, 0x80000000 | 29, QMC::Readable | QMC::Scriptable | QMC::Stored | QMC::EnumOrFlag, 7),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NetItem, qt_meta_tag_ZN3dde7network7NetItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN3dde7network7NetItemE[] = {
    QMetaObject::SuperData::link<dde::network::NetType::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject dde::network::NetItem::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network7NetItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network7NetItemE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN3dde7network7NetItemE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network7NetItemE_t>.metaTypes,
    nullptr
} };

void dde::network::NetItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NetItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->idChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->nameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->dataChanged(); break;
        case 3: _t->childAboutToBeAdded((*reinterpret_cast<std::add_pointer_t<const NetItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 4: _t->childAdded((*reinterpret_cast<std::add_pointer_t<const NetItem*>>(_a[1]))); break;
        case 5: _t->childAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<const NetItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 6: _t->childRemoved((*reinterpret_cast<std::add_pointer_t<const NetItem*>>(_a[1]))); break;
        case 7: _t->childrenChanged(); break;
        case 8: { NetItem* _r = _t->getChild((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<NetItem**>(_a[0]) = std::move(_r); }  break;
        case 9: { int _r = _t->getChildIndex((*reinterpret_cast<std::add_pointer_t<const NetItem*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 10: { int _r = _t->getChildrenNumber();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->getChildren(); break;
        case 12: { int _r = _t->getIndex();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 13: { NetItem* _r = _t->getParent();
            if (_a[0]) *reinterpret_cast<NetItem**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NetItem::*)(const QString & , const QString & )>(_a, &NetItem::idChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetItem::*)(const QString & )>(_a, &NetItem::nameChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetItem::*)()>(_a, &NetItem::dataChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetItem::*)(const NetItem * , int )>(_a, &NetItem::childAboutToBeAdded, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetItem::*)(const NetItem * )>(_a, &NetItem::childAdded, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetItem::*)(const NetItem * , int )>(_a, &NetItem::childAboutToBeRemoved, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetItem::*)(const NetItem * )>(_a, &NetItem::childRemoved, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetItem::*)()>(_a, &NetItem::childrenChanged, 7))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<NetItem*> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->id(); break;
        case 1: *reinterpret_cast<NetType::NetItemType*>(_v) = _t->itemType(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 3: *reinterpret_cast<QList<NetItem*>*>(_v) = _t->getChildren(); break;
        default: break;
        }
    }
}

const QMetaObject *dde::network::NetItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::NetItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network7NetItemE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dde::network::NetItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void dde::network::NetItem::idChanged(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void dde::network::NetItem::nameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void dde::network::NetItem::dataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void dde::network::NetItem::childAboutToBeAdded(const NetItem * _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void dde::network::NetItem::childAdded(const NetItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void dde::network::NetItem::childAboutToBeRemoved(const NetItem * _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void dde::network::NetItem::childRemoved(const NetItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void dde::network::NetItem::childrenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
namespace {
struct qt_meta_tag_ZN3dde7network14NetControlItemE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::NetControlItem::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network14NetControlItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::NetControlItem",
        "enabledChanged",
        "",
        "enabledableChanged",
        "isEnabled",
        "enabledable"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void(const bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'enabledableChanged'
        QtMocHelpers::SignalData<void(const bool)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'isEnabled'
        QtMocHelpers::PropertyData<bool>(4, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'enabledable'
        QtMocHelpers::PropertyData<bool>(5, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NetControlItem, qt_meta_tag_ZN3dde7network14NetControlItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::NetControlItem::staticMetaObject = { {
    QMetaObject::SuperData::link<NetItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network14NetControlItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network14NetControlItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network14NetControlItemE_t>.metaTypes,
    nullptr
} };

void dde::network::NetControlItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NetControlItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->enabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->enabledableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NetControlItem::*)(const bool )>(_a, &NetControlItem::enabledChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetControlItem::*)(const bool )>(_a, &NetControlItem::enabledableChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isEnabled(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->enabledable(); break;
        default: break;
        }
    }
}

const QMetaObject *dde::network::NetControlItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::NetControlItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network14NetControlItemE_t>.strings))
        return static_cast<void*>(this);
    return NetItem::qt_metacast(_clname);
}

int dde::network::NetControlItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NetItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void dde::network::NetControlItem::enabledChanged(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void dde::network::NetControlItem::enabledableChanged(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN3dde7network13NetDeviceItemE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::NetDeviceItem::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network13NetDeviceItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::NetDeviceItem",
        "statusChanged",
        "",
        "NetType::NetDeviceStatus",
        "status",
        "ipsChanged",
        "ips",
        "pathIndexChanged",
        "pathIndex"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'statusChanged'
        QtMocHelpers::SignalData<void(const NetType::NetDeviceStatus)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'ipsChanged'
        QtMocHelpers::SignalData<void(const QStringList &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 6 },
        }}),
        // Signal 'pathIndexChanged'
        QtMocHelpers::SignalData<void(const int &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'status'
        QtMocHelpers::PropertyData<NetType::NetDeviceStatus>(4, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'ips'
        QtMocHelpers::PropertyData<QStringList>(6, QMetaType::QStringList, QMC::DefaultPropertyFlags, 1),
        // property 'pathIndex'
        QtMocHelpers::PropertyData<int>(8, QMetaType::Int, QMC::DefaultPropertyFlags, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NetDeviceItem, qt_meta_tag_ZN3dde7network13NetDeviceItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN3dde7network13NetDeviceItemE[] = {
    QMetaObject::SuperData::link<dde::network::NetType::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject dde::network::NetDeviceItem::staticMetaObject = { {
    QMetaObject::SuperData::link<NetControlItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network13NetDeviceItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network13NetDeviceItemE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN3dde7network13NetDeviceItemE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network13NetDeviceItemE_t>.metaTypes,
    nullptr
} };

void dde::network::NetDeviceItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NetDeviceItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->statusChanged((*reinterpret_cast<std::add_pointer_t<NetType::NetDeviceStatus>>(_a[1]))); break;
        case 1: _t->ipsChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 2: _t->pathIndexChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NetDeviceItem::*)(const NetType::NetDeviceStatus )>(_a, &NetDeviceItem::statusChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetDeviceItem::*)(const QStringList & )>(_a, &NetDeviceItem::ipsChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetDeviceItem::*)(const int & )>(_a, &NetDeviceItem::pathIndexChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<NetType::NetDeviceStatus*>(_v) = _t->status(); break;
        case 1: *reinterpret_cast<QStringList*>(_v) = _t->ips(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->pathIndex(); break;
        default: break;
        }
    }
}

const QMetaObject *dde::network::NetDeviceItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::NetDeviceItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network13NetDeviceItemE_t>.strings))
        return static_cast<void*>(this);
    return NetControlItem::qt_metacast(_clname);
}

int dde::network::NetDeviceItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NetControlItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void dde::network::NetDeviceItem::statusChanged(const NetType::NetDeviceStatus _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void dde::network::NetDeviceItem::ipsChanged(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void dde::network::NetDeviceItem::pathIndexChanged(const int & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN3dde7network19NetWiredControlItemE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::NetWiredControlItem::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network19NetWiredControlItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::NetWiredControlItem"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NetWiredControlItem, qt_meta_tag_ZN3dde7network19NetWiredControlItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::NetWiredControlItem::staticMetaObject = { {
    QMetaObject::SuperData::link<NetControlItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network19NetWiredControlItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network19NetWiredControlItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network19NetWiredControlItemE_t>.metaTypes,
    nullptr
} };

void dde::network::NetWiredControlItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NetWiredControlItem *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *dde::network::NetWiredControlItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::NetWiredControlItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network19NetWiredControlItemE_t>.strings))
        return static_cast<void*>(this);
    return NetControlItem::qt_metacast(_clname);
}

int dde::network::NetWiredControlItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NetControlItem::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN3dde7network22NetWirelessControlItemE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::NetWirelessControlItem::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network22NetWirelessControlItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::NetWirelessControlItem"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NetWirelessControlItem, qt_meta_tag_ZN3dde7network22NetWirelessControlItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::NetWirelessControlItem::staticMetaObject = { {
    QMetaObject::SuperData::link<NetControlItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network22NetWirelessControlItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network22NetWirelessControlItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network22NetWirelessControlItemE_t>.metaTypes,
    nullptr
} };

void dde::network::NetWirelessControlItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NetWirelessControlItem *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *dde::network::NetWirelessControlItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::NetWirelessControlItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network22NetWirelessControlItemE_t>.strings))
        return static_cast<void*>(this);
    return NetControlItem::qt_metacast(_clname);
}

int dde::network::NetWirelessControlItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NetControlItem::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN3dde7network11NetTipsItemE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::NetTipsItem::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network11NetTipsItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::NetTipsItem",
        "linkActivatedTextChanged",
        "",
        "text",
        "tipsLinkEnabledChanged",
        "enable"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'linkActivatedTextChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'tipsLinkEnabledChanged'
        QtMocHelpers::SignalData<void(bool) const>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NetTipsItem, qt_meta_tag_ZN3dde7network11NetTipsItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::NetTipsItem::staticMetaObject = { {
    QMetaObject::SuperData::link<NetItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network11NetTipsItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network11NetTipsItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network11NetTipsItemE_t>.metaTypes,
    nullptr
} };

void dde::network::NetTipsItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NetTipsItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->linkActivatedTextChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->tipsLinkEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NetTipsItem::*)(const QString & ) const>(_a, &NetTipsItem::linkActivatedTextChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetTipsItem::*)(bool ) const>(_a, &NetTipsItem::tipsLinkEnabledChanged, 1))
            return;
    }
}

const QMetaObject *dde::network::NetTipsItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::NetTipsItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network11NetTipsItemE_t>.strings))
        return static_cast<void*>(this);
    return NetItem::qt_metacast(_clname);
}

int dde::network::NetTipsItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NetItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void dde::network::NetTipsItem::linkActivatedTextChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< dde::network::NetTipsItem *>(this), &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void dde::network::NetTipsItem::tipsLinkEnabledChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< dde::network::NetTipsItem *>(this), &staticMetaObject, 1, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN3dde7network18NetWiredDeviceItemE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::NetWiredDeviceItem::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network18NetWiredDeviceItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::NetWiredDeviceItem"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NetWiredDeviceItem, qt_meta_tag_ZN3dde7network18NetWiredDeviceItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::NetWiredDeviceItem::staticMetaObject = { {
    QMetaObject::SuperData::link<NetDeviceItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network18NetWiredDeviceItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network18NetWiredDeviceItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network18NetWiredDeviceItemE_t>.metaTypes,
    nullptr
} };

void dde::network::NetWiredDeviceItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NetWiredDeviceItem *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *dde::network::NetWiredDeviceItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::NetWiredDeviceItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network18NetWiredDeviceItemE_t>.strings))
        return static_cast<void*>(this);
    return NetDeviceItem::qt_metacast(_clname);
}

int dde::network::NetWiredDeviceItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NetDeviceItem::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN3dde7network21NetWirelessDeviceItemE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::NetWirelessDeviceItem::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network21NetWirelessDeviceItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::NetWirelessDeviceItem",
        "apModeChanged",
        "",
        "apMode"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'apModeChanged'
        QtMocHelpers::SignalData<void(bool) const>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'apMode'
        QtMocHelpers::PropertyData<bool>(3, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NetWirelessDeviceItem, qt_meta_tag_ZN3dde7network21NetWirelessDeviceItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::NetWirelessDeviceItem::staticMetaObject = { {
    QMetaObject::SuperData::link<NetDeviceItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network21NetWirelessDeviceItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network21NetWirelessDeviceItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network21NetWirelessDeviceItemE_t>.metaTypes,
    nullptr
} };

void dde::network::NetWirelessDeviceItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NetWirelessDeviceItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->apModeChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NetWirelessDeviceItem::*)(bool ) const>(_a, &NetWirelessDeviceItem::apModeChanged, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->apMode(); break;
        default: break;
        }
    }
}

const QMetaObject *dde::network::NetWirelessDeviceItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::NetWirelessDeviceItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network21NetWirelessDeviceItemE_t>.strings))
        return static_cast<void*>(this);
    return NetDeviceItem::qt_metacast(_clname);
}

int dde::network::NetWirelessDeviceItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NetDeviceItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void dde::network::NetWirelessDeviceItem::apModeChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< dde::network::NetWirelessDeviceItem *>(this), &staticMetaObject, 0, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN3dde7network23NetAirplaneModeTipsItemE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::NetAirplaneModeTipsItem::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network23NetAirplaneModeTipsItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::NetAirplaneModeTipsItem"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NetAirplaneModeTipsItem, qt_meta_tag_ZN3dde7network23NetAirplaneModeTipsItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::NetAirplaneModeTipsItem::staticMetaObject = { {
    QMetaObject::SuperData::link<NetTipsItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network23NetAirplaneModeTipsItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network23NetAirplaneModeTipsItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network23NetAirplaneModeTipsItemE_t>.metaTypes,
    nullptr
} };

void dde::network::NetAirplaneModeTipsItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NetAirplaneModeTipsItem *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *dde::network::NetAirplaneModeTipsItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::NetAirplaneModeTipsItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network23NetAirplaneModeTipsItemE_t>.strings))
        return static_cast<void*>(this);
    return NetTipsItem::qt_metacast(_clname);
}

int dde::network::NetAirplaneModeTipsItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NetTipsItem::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN3dde7network17NetConnectionItemE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::NetConnectionItem::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network17NetConnectionItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::NetConnectionItem",
        "statusChanged",
        "",
        "NetType::NetConnectionStatus",
        "status"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'statusChanged'
        QtMocHelpers::SignalData<void(NetType::NetConnectionStatus)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'status'
        QtMocHelpers::PropertyData<NetType::NetConnectionStatus>(4, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NetConnectionItem, qt_meta_tag_ZN3dde7network17NetConnectionItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN3dde7network17NetConnectionItemE[] = {
    QMetaObject::SuperData::link<dde::network::NetType::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject dde::network::NetConnectionItem::staticMetaObject = { {
    QMetaObject::SuperData::link<NetItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network17NetConnectionItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network17NetConnectionItemE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN3dde7network17NetConnectionItemE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network17NetConnectionItemE_t>.metaTypes,
    nullptr
} };

void dde::network::NetConnectionItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NetConnectionItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->statusChanged((*reinterpret_cast<std::add_pointer_t<NetType::NetConnectionStatus>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NetConnectionItem::*)(NetType::NetConnectionStatus )>(_a, &NetConnectionItem::statusChanged, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<NetType::NetConnectionStatus*>(_v) = _t->status(); break;
        default: break;
        }
    }
}

const QMetaObject *dde::network::NetConnectionItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::NetConnectionItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network17NetConnectionItemE_t>.strings))
        return static_cast<void*>(this);
    return NetItem::qt_metacast(_clname);
}

int dde::network::NetConnectionItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NetItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void dde::network::NetConnectionItem::statusChanged(NetType::NetConnectionStatus _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN3dde7network12NetWiredItemE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::NetWiredItem::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network12NetWiredItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::NetWiredItem"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NetWiredItem, qt_meta_tag_ZN3dde7network12NetWiredItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::NetWiredItem::staticMetaObject = { {
    QMetaObject::SuperData::link<NetConnectionItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network12NetWiredItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network12NetWiredItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network12NetWiredItemE_t>.metaTypes,
    nullptr
} };

void dde::network::NetWiredItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NetWiredItem *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *dde::network::NetWiredItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::NetWiredItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network12NetWiredItemE_t>.strings))
        return static_cast<void*>(this);
    return NetConnectionItem::qt_metacast(_clname);
}

int dde::network::NetWiredItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NetConnectionItem::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN3dde7network20NetWiredDisabledItemE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::NetWiredDisabledItem::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network20NetWiredDisabledItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::NetWiredDisabledItem"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NetWiredDisabledItem, qt_meta_tag_ZN3dde7network20NetWiredDisabledItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::NetWiredDisabledItem::staticMetaObject = { {
    QMetaObject::SuperData::link<NetItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network20NetWiredDisabledItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network20NetWiredDisabledItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network20NetWiredDisabledItemE_t>.metaTypes,
    nullptr
} };

void dde::network::NetWiredDisabledItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NetWiredDisabledItem *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *dde::network::NetWiredDisabledItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::NetWiredDisabledItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network20NetWiredDisabledItemE_t>.strings))
        return static_cast<void*>(this);
    return NetItem::qt_metacast(_clname);
}

int dde::network::NetWiredDisabledItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NetItem::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN3dde7network21NetWirelessHiddenItemE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::NetWirelessHiddenItem::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network21NetWirelessHiddenItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::NetWirelessHiddenItem"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NetWirelessHiddenItem, qt_meta_tag_ZN3dde7network21NetWirelessHiddenItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::NetWirelessHiddenItem::staticMetaObject = { {
    QMetaObject::SuperData::link<NetItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network21NetWirelessHiddenItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network21NetWirelessHiddenItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network21NetWirelessHiddenItemE_t>.metaTypes,
    nullptr
} };

void dde::network::NetWirelessHiddenItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NetWirelessHiddenItem *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *dde::network::NetWirelessHiddenItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::NetWirelessHiddenItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network21NetWirelessHiddenItemE_t>.strings))
        return static_cast<void*>(this);
    return NetItem::qt_metacast(_clname);
}

int dde::network::NetWirelessHiddenItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NetItem::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN3dde7network15NetWirelessItemE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::NetWirelessItem::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network15NetWirelessItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::NetWirelessItem",
        "flagsChanged",
        "",
        "flags",
        "strengthChanged",
        "strength",
        "strengthLevelChanged",
        "strengthLevel",
        "secureChanged",
        "secure",
        "hasConnectionChanged",
        "hasConnection"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'flagsChanged'
        QtMocHelpers::SignalData<void(uint)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'strengthChanged'
        QtMocHelpers::SignalData<void(int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Signal 'strengthLevelChanged'
        QtMocHelpers::SignalData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'secureChanged'
        QtMocHelpers::SignalData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Signal 'hasConnectionChanged'
        QtMocHelpers::SignalData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'flags'
        QtMocHelpers::PropertyData<uint>(3, QMetaType::UInt, QMC::DefaultPropertyFlags, 0),
        // property 'strength'
        QtMocHelpers::PropertyData<int>(5, QMetaType::Int, QMC::DefaultPropertyFlags, 1),
        // property 'strengthLevel'
        QtMocHelpers::PropertyData<int>(7, QMetaType::Int, QMC::DefaultPropertyFlags, 2),
        // property 'secure'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'hasConnection'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NetWirelessItem, qt_meta_tag_ZN3dde7network15NetWirelessItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::NetWirelessItem::staticMetaObject = { {
    QMetaObject::SuperData::link<NetConnectionItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network15NetWirelessItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network15NetWirelessItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network15NetWirelessItemE_t>.metaTypes,
    nullptr
} };

void dde::network::NetWirelessItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NetWirelessItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->flagsChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 1: _t->strengthChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->strengthLevelChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->secureChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->hasConnectionChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NetWirelessItem::*)(uint )>(_a, &NetWirelessItem::flagsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetWirelessItem::*)(int )>(_a, &NetWirelessItem::strengthChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetWirelessItem::*)(int )>(_a, &NetWirelessItem::strengthLevelChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetWirelessItem::*)(bool )>(_a, &NetWirelessItem::secureChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetWirelessItem::*)(bool )>(_a, &NetWirelessItem::hasConnectionChanged, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<uint*>(_v) = _t->flags(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->strength(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->strengthLevel(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isSecure(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->hasConnection(); break;
        default: break;
        }
    }
}

const QMetaObject *dde::network::NetWirelessItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::NetWirelessItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network15NetWirelessItemE_t>.strings))
        return static_cast<void*>(this);
    return NetConnectionItem::qt_metacast(_clname);
}

int dde::network::NetWirelessItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NetConnectionItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void dde::network::NetWirelessItem::flagsChanged(uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void dde::network::NetWirelessItem::strengthChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void dde::network::NetWirelessItem::strengthLevelChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void dde::network::NetWirelessItem::secureChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void dde::network::NetWirelessItem::hasConnectionChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN3dde7network20NetWirelessOtherItemE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::NetWirelessOtherItem::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network20NetWirelessOtherItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::NetWirelessOtherItem",
        "expandedChanged",
        "",
        "expanded"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'expandedChanged'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NetWirelessOtherItem, qt_meta_tag_ZN3dde7network20NetWirelessOtherItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::NetWirelessOtherItem::staticMetaObject = { {
    QMetaObject::SuperData::link<NetItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network20NetWirelessOtherItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network20NetWirelessOtherItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network20NetWirelessOtherItemE_t>.metaTypes,
    nullptr
} };

void dde::network::NetWirelessOtherItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NetWirelessOtherItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->expandedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NetWirelessOtherItem::*)(bool )>(_a, &NetWirelessOtherItem::expandedChanged, 0))
            return;
    }
}

const QMetaObject *dde::network::NetWirelessOtherItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::NetWirelessOtherItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network20NetWirelessOtherItemE_t>.strings))
        return static_cast<void*>(this);
    return NetItem::qt_metacast(_clname);
}

int dde::network::NetWirelessOtherItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NetItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void dde::network::NetWirelessOtherItem::expandedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN3dde7network19NetWirelessMineItemE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::NetWirelessMineItem::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network19NetWirelessMineItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::NetWirelessMineItem"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NetWirelessMineItem, qt_meta_tag_ZN3dde7network19NetWirelessMineItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::NetWirelessMineItem::staticMetaObject = { {
    QMetaObject::SuperData::link<NetItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network19NetWirelessMineItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network19NetWirelessMineItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network19NetWirelessMineItemE_t>.metaTypes,
    nullptr
} };

void dde::network::NetWirelessMineItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NetWirelessMineItem *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *dde::network::NetWirelessMineItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::NetWirelessMineItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network19NetWirelessMineItemE_t>.strings))
        return static_cast<void*>(this);
    return NetItem::qt_metacast(_clname);
}

int dde::network::NetWirelessMineItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NetItem::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN3dde7network23NetWirelessDisabledItemE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::NetWirelessDisabledItem::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network23NetWirelessDisabledItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::NetWirelessDisabledItem"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NetWirelessDisabledItem, qt_meta_tag_ZN3dde7network23NetWirelessDisabledItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::NetWirelessDisabledItem::staticMetaObject = { {
    QMetaObject::SuperData::link<NetItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network23NetWirelessDisabledItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network23NetWirelessDisabledItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network23NetWirelessDisabledItemE_t>.metaTypes,
    nullptr
} };

void dde::network::NetWirelessDisabledItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NetWirelessDisabledItem *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *dde::network::NetWirelessDisabledItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::NetWirelessDisabledItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network23NetWirelessDisabledItemE_t>.strings))
        return static_cast<void*>(this);
    return NetItem::qt_metacast(_clname);
}

int dde::network::NetWirelessDisabledItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NetItem::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN3dde7network17NetVPNControlItemE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::NetVPNControlItem::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network17NetVPNControlItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::NetVPNControlItem",
        "expandedChanged",
        "",
        "expanded"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'expandedChanged'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NetVPNControlItem, qt_meta_tag_ZN3dde7network17NetVPNControlItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::NetVPNControlItem::staticMetaObject = { {
    QMetaObject::SuperData::link<NetDeviceItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network17NetVPNControlItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network17NetVPNControlItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network17NetVPNControlItemE_t>.metaTypes,
    nullptr
} };

void dde::network::NetVPNControlItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NetVPNControlItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->expandedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NetVPNControlItem::*)(bool )>(_a, &NetVPNControlItem::expandedChanged, 0))
            return;
    }
}

const QMetaObject *dde::network::NetVPNControlItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::NetVPNControlItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network17NetVPNControlItemE_t>.strings))
        return static_cast<void*>(this);
    return NetDeviceItem::qt_metacast(_clname);
}

int dde::network::NetVPNControlItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NetDeviceItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void dde::network::NetVPNControlItem::expandedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN3dde7network14NetVPNTipsItemE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::NetVPNTipsItem::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network14NetVPNTipsItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::NetVPNTipsItem"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NetVPNTipsItem, qt_meta_tag_ZN3dde7network14NetVPNTipsItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::NetVPNTipsItem::staticMetaObject = { {
    QMetaObject::SuperData::link<NetTipsItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network14NetVPNTipsItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network14NetVPNTipsItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network14NetVPNTipsItemE_t>.metaTypes,
    nullptr
} };

void dde::network::NetVPNTipsItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NetVPNTipsItem *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *dde::network::NetVPNTipsItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::NetVPNTipsItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network14NetVPNTipsItemE_t>.strings))
        return static_cast<void*>(this);
    return NetTipsItem::qt_metacast(_clname);
}

int dde::network::NetVPNTipsItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NetTipsItem::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN3dde7network25NetSystemProxyControlItemE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::NetSystemProxyControlItem::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network25NetSystemProxyControlItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::NetSystemProxyControlItem",
        "lastMethodChanged",
        "",
        "NetType::ProxyMethod",
        "method",
        "methodChanged",
        "autoProxyChanged",
        "autoProxy",
        "manualProxyChanged",
        "QVariantMap",
        "manualProxy",
        "lastMethod"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'lastMethodChanged'
        QtMocHelpers::SignalData<void(NetType::ProxyMethod)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'methodChanged'
        QtMocHelpers::SignalData<void(NetType::ProxyMethod)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'autoProxyChanged'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'manualProxyChanged'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'lastMethod'
        QtMocHelpers::PropertyData<NetType::ProxyMethod>(11, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'method'
        QtMocHelpers::PropertyData<NetType::ProxyMethod>(4, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'autoProxy'
        QtMocHelpers::PropertyData<QString>(7, QMetaType::QString, QMC::DefaultPropertyFlags, 2),
        // property 'manualProxy'
        QtMocHelpers::PropertyData<QVariantMap>(10, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NetSystemProxyControlItem, qt_meta_tag_ZN3dde7network25NetSystemProxyControlItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN3dde7network25NetSystemProxyControlItemE[] = {
    QMetaObject::SuperData::link<dde::network::NetType::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject dde::network::NetSystemProxyControlItem::staticMetaObject = { {
    QMetaObject::SuperData::link<NetControlItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network25NetSystemProxyControlItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network25NetSystemProxyControlItemE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN3dde7network25NetSystemProxyControlItemE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network25NetSystemProxyControlItemE_t>.metaTypes,
    nullptr
} };

void dde::network::NetSystemProxyControlItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NetSystemProxyControlItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->lastMethodChanged((*reinterpret_cast<std::add_pointer_t<NetType::ProxyMethod>>(_a[1]))); break;
        case 1: _t->methodChanged((*reinterpret_cast<std::add_pointer_t<NetType::ProxyMethod>>(_a[1]))); break;
        case 2: _t->autoProxyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->manualProxyChanged((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NetSystemProxyControlItem::*)(NetType::ProxyMethod )>(_a, &NetSystemProxyControlItem::lastMethodChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetSystemProxyControlItem::*)(NetType::ProxyMethod )>(_a, &NetSystemProxyControlItem::methodChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetSystemProxyControlItem::*)(const QString & )>(_a, &NetSystemProxyControlItem::autoProxyChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetSystemProxyControlItem::*)(const QVariantMap & )>(_a, &NetSystemProxyControlItem::manualProxyChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<NetType::ProxyMethod*>(_v) = _t->lastMethod(); break;
        case 1: *reinterpret_cast<NetType::ProxyMethod*>(_v) = _t->method(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->autoProxy(); break;
        case 3: *reinterpret_cast<QVariantMap*>(_v) = _t->manualProxy(); break;
        default: break;
        }
    }
}

const QMetaObject *dde::network::NetSystemProxyControlItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::NetSystemProxyControlItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network25NetSystemProxyControlItemE_t>.strings))
        return static_cast<void*>(this);
    return NetControlItem::qt_metacast(_clname);
}

int dde::network::NetSystemProxyControlItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NetControlItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void dde::network::NetSystemProxyControlItem::lastMethodChanged(NetType::ProxyMethod _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void dde::network::NetSystemProxyControlItem::methodChanged(NetType::ProxyMethod _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void dde::network::NetSystemProxyControlItem::autoProxyChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void dde::network::NetSystemProxyControlItem::manualProxyChanged(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN3dde7network22NetAppProxyControlItemE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::NetAppProxyControlItem::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network22NetAppProxyControlItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::NetAppProxyControlItem",
        "configChanged",
        "",
        "QVariantMap",
        "config"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'configChanged'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'config'
        QtMocHelpers::PropertyData<QVariantMap>(4, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NetAppProxyControlItem, qt_meta_tag_ZN3dde7network22NetAppProxyControlItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::NetAppProxyControlItem::staticMetaObject = { {
    QMetaObject::SuperData::link<NetControlItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network22NetAppProxyControlItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network22NetAppProxyControlItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network22NetAppProxyControlItemE_t>.metaTypes,
    nullptr
} };

void dde::network::NetAppProxyControlItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NetAppProxyControlItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->configChanged((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NetAppProxyControlItem::*)(const QVariantMap & )>(_a, &NetAppProxyControlItem::configChanged, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QVariantMap*>(_v) = _t->config(); break;
        default: break;
        }
    }
}

const QMetaObject *dde::network::NetAppProxyControlItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::NetAppProxyControlItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network22NetAppProxyControlItemE_t>.strings))
        return static_cast<void*>(this);
    return NetControlItem::qt_metacast(_clname);
}

int dde::network::NetAppProxyControlItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NetControlItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void dde::network::NetAppProxyControlItem::configChanged(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN3dde7network21NetHotspotControlItemE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::NetHotspotControlItem::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network21NetHotspotControlItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::NetHotspotControlItem",
        "configChanged",
        "",
        "QVariantMap",
        "config",
        "optionalDeviceChanged",
        "optionalDevice",
        "shareDeviceChanged",
        "shareDevice"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'configChanged'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'optionalDeviceChanged'
        QtMocHelpers::SignalData<void(const QStringList &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 6 },
        }}),
        // Signal 'shareDeviceChanged'
        QtMocHelpers::SignalData<void(const QStringList &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'config'
        QtMocHelpers::PropertyData<QVariantMap>(4, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'optionalDevice'
        QtMocHelpers::PropertyData<QStringList>(6, QMetaType::QStringList, QMC::DefaultPropertyFlags, 1),
        // property 'shareDevice'
        QtMocHelpers::PropertyData<QStringList>(8, QMetaType::QStringList, QMC::DefaultPropertyFlags, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NetHotspotControlItem, qt_meta_tag_ZN3dde7network21NetHotspotControlItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::NetHotspotControlItem::staticMetaObject = { {
    QMetaObject::SuperData::link<NetControlItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network21NetHotspotControlItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network21NetHotspotControlItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network21NetHotspotControlItemE_t>.metaTypes,
    nullptr
} };

void dde::network::NetHotspotControlItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NetHotspotControlItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->configChanged((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 1: _t->optionalDeviceChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 2: _t->shareDeviceChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NetHotspotControlItem::*)(const QVariantMap & )>(_a, &NetHotspotControlItem::configChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetHotspotControlItem::*)(const QStringList & )>(_a, &NetHotspotControlItem::optionalDeviceChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetHotspotControlItem::*)(const QStringList & )>(_a, &NetHotspotControlItem::shareDeviceChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QVariantMap*>(_v) = _t->config(); break;
        case 1: *reinterpret_cast<QStringList*>(_v) = _t->optionalDevice(); break;
        case 2: *reinterpret_cast<QStringList*>(_v) = _t->shareDevice(); break;
        default: break;
        }
    }
}

const QMetaObject *dde::network::NetHotspotControlItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::NetHotspotControlItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network21NetHotspotControlItemE_t>.strings))
        return static_cast<void*>(this);
    return NetControlItem::qt_metacast(_clname);
}

int dde::network::NetHotspotControlItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NetControlItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void dde::network::NetHotspotControlItem::configChanged(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void dde::network::NetHotspotControlItem::optionalDeviceChanged(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void dde::network::NetHotspotControlItem::shareDeviceChanged(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN3dde7network22NetAirplaneControlItemE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::NetAirplaneControlItem::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network22NetAirplaneControlItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::NetAirplaneControlItem"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NetAirplaneControlItem, qt_meta_tag_ZN3dde7network22NetAirplaneControlItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::NetAirplaneControlItem::staticMetaObject = { {
    QMetaObject::SuperData::link<NetControlItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network22NetAirplaneControlItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network22NetAirplaneControlItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network22NetAirplaneControlItemE_t>.metaTypes,
    nullptr
} };

void dde::network::NetAirplaneControlItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NetAirplaneControlItem *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *dde::network::NetAirplaneControlItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::NetAirplaneControlItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network22NetAirplaneControlItemE_t>.strings))
        return static_cast<void*>(this);
    return NetControlItem::qt_metacast(_clname);
}

int dde::network::NetAirplaneControlItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NetControlItem::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN3dde7network17NetDSLControlItemE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::NetDSLControlItem::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network17NetDSLControlItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::NetDSLControlItem"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NetDSLControlItem, qt_meta_tag_ZN3dde7network17NetDSLControlItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::NetDSLControlItem::staticMetaObject = { {
    QMetaObject::SuperData::link<NetControlItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network17NetDSLControlItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network17NetDSLControlItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network17NetDSLControlItemE_t>.metaTypes,
    nullptr
} };

void dde::network::NetDSLControlItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NetDSLControlItem *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *dde::network::NetDSLControlItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::NetDSLControlItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network17NetDSLControlItemE_t>.strings))
        return static_cast<void*>(this);
    return NetControlItem::qt_metacast(_clname);
}

int dde::network::NetDSLControlItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NetControlItem::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN3dde7network14NetDetailsItemE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::NetDetailsItem::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network14NetDetailsItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::NetDetailsItem"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NetDetailsItem, qt_meta_tag_ZN3dde7network14NetDetailsItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::NetDetailsItem::staticMetaObject = { {
    QMetaObject::SuperData::link<NetItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network14NetDetailsItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network14NetDetailsItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network14NetDetailsItemE_t>.metaTypes,
    nullptr
} };

void dde::network::NetDetailsItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NetDetailsItem *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *dde::network::NetDetailsItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::NetDetailsItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network14NetDetailsItemE_t>.strings))
        return static_cast<void*>(this);
    return NetItem::qt_metacast(_clname);
}

int dde::network::NetDetailsItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NetItem::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN3dde7network18NetDetailsInfoItemE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::NetDetailsInfoItem::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network18NetDetailsInfoItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::NetDetailsInfoItem",
        "detailsChanged",
        "",
        "QList<QStringList>",
        "details",
        "indexChanged",
        "index"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'detailsChanged'
        QtMocHelpers::SignalData<void(const QList<QStringList> &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'indexChanged'
        QtMocHelpers::SignalData<void(const int &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'details'
        QtMocHelpers::PropertyData<QList<QStringList>>(4, 0x80000000 | 3, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'index'
        QtMocHelpers::PropertyData<int>(6, QMetaType::Int, QMC::DefaultPropertyFlags, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NetDetailsInfoItem, qt_meta_tag_ZN3dde7network18NetDetailsInfoItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::NetDetailsInfoItem::staticMetaObject = { {
    QMetaObject::SuperData::link<NetItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network18NetDetailsInfoItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network18NetDetailsInfoItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network18NetDetailsInfoItemE_t>.metaTypes,
    nullptr
} };

void dde::network::NetDetailsInfoItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NetDetailsInfoItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->detailsChanged((*reinterpret_cast<std::add_pointer_t<QList<QStringList>>>(_a[1]))); break;
        case 1: _t->indexChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QStringList> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NetDetailsInfoItem::*)(const QList<QStringList> & )>(_a, &NetDetailsInfoItem::detailsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetDetailsInfoItem::*)(const int & )>(_a, &NetDetailsInfoItem::indexChanged, 1))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QStringList> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QList<QStringList>*>(_v) = _t->details(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->index(); break;
        default: break;
        }
    }
}

const QMetaObject *dde::network::NetDetailsInfoItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::NetDetailsInfoItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network18NetDetailsInfoItemE_t>.strings))
        return static_cast<void*>(this);
    return NetItem::qt_metacast(_clname);
}

int dde::network::NetDetailsInfoItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NetItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void dde::network::NetDetailsInfoItem::detailsChanged(const QList<QStringList> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void dde::network::NetDetailsInfoItem::indexChanged(const int & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
