/****************************************************************************
** Meta object code from reading C++ file 'hotspotcontroller.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../impl/hotspotcontroller.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'hotspotcontroller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3dde7network17HotspotControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::HotspotController::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network17HotspotControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::HotspotController",
        "enabledChanged",
        "",
        "itemAdded",
        "QMap<WirelessDevice*,QList<HotspotItem*>>",
        "itemRemoved",
        "itemChanged",
        "activeConnectionChanged",
        "QList<WirelessDevice*>",
        "deviceAdded",
        "deviceRemove",
        "enableHotspotSwitch"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void(const bool &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'itemAdded'
        QtMocHelpers::SignalData<void(const QMap<WirelessDevice*,QList<HotspotItem*>> &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Signal 'itemRemoved'
        QtMocHelpers::SignalData<void(const QMap<WirelessDevice*,QList<HotspotItem*>> &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Signal 'itemChanged'
        QtMocHelpers::SignalData<void(const QMap<WirelessDevice*,QList<HotspotItem*>> &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Signal 'activeConnectionChanged'
        QtMocHelpers::SignalData<void(const QList<WirelessDevice*> &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Signal 'deviceAdded'
        QtMocHelpers::SignalData<void(const QList<WirelessDevice*> &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Signal 'deviceRemove'
        QtMocHelpers::SignalData<void(const QList<WirelessDevice*> &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Signal 'enableHotspotSwitch'
        QtMocHelpers::SignalData<void(const bool &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<HotspotController, qt_meta_tag_ZN3dde7network17HotspotControllerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::HotspotController::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network17HotspotControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network17HotspotControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network17HotspotControllerE_t>.metaTypes,
    nullptr
} };

void dde::network::HotspotController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<HotspotController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->enabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->itemAdded((*reinterpret_cast<std::add_pointer_t<QMap<WirelessDevice*,QList<HotspotItem*>>>>(_a[1]))); break;
        case 2: _t->itemRemoved((*reinterpret_cast<std::add_pointer_t<QMap<WirelessDevice*,QList<HotspotItem*>>>>(_a[1]))); break;
        case 3: _t->itemChanged((*reinterpret_cast<std::add_pointer_t<QMap<WirelessDevice*,QList<HotspotItem*>>>>(_a[1]))); break;
        case 4: _t->activeConnectionChanged((*reinterpret_cast<std::add_pointer_t<QList<WirelessDevice*>>>(_a[1]))); break;
        case 5: _t->deviceAdded((*reinterpret_cast<std::add_pointer_t<QList<WirelessDevice*>>>(_a[1]))); break;
        case 6: _t->deviceRemove((*reinterpret_cast<std::add_pointer_t<QList<WirelessDevice*>>>(_a[1]))); break;
        case 7: _t->enableHotspotSwitch((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (HotspotController::*)(const bool & )>(_a, &HotspotController::enabledChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (HotspotController::*)(const QMap<WirelessDevice*,QList<HotspotItem*>> & )>(_a, &HotspotController::itemAdded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (HotspotController::*)(const QMap<WirelessDevice*,QList<HotspotItem*>> & )>(_a, &HotspotController::itemRemoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (HotspotController::*)(const QMap<WirelessDevice*,QList<HotspotItem*>> & )>(_a, &HotspotController::itemChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (HotspotController::*)(const QList<WirelessDevice*> & )>(_a, &HotspotController::activeConnectionChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (HotspotController::*)(const QList<WirelessDevice*> & )>(_a, &HotspotController::deviceAdded, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (HotspotController::*)(const QList<WirelessDevice*> & )>(_a, &HotspotController::deviceRemove, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (HotspotController::*)(const bool & )>(_a, &HotspotController::enableHotspotSwitch, 7))
            return;
    }
}

const QMetaObject *dde::network::HotspotController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::HotspotController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network17HotspotControllerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dde::network::HotspotController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void dde::network::HotspotController::enabledChanged(const bool & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void dde::network::HotspotController::itemAdded(const QMap<WirelessDevice*,QList<HotspotItem*>> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void dde::network::HotspotController::itemRemoved(const QMap<WirelessDevice*,QList<HotspotItem*>> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void dde::network::HotspotController::itemChanged(const QMap<WirelessDevice*,QList<HotspotItem*>> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void dde::network::HotspotController::activeConnectionChanged(const QList<WirelessDevice*> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void dde::network::HotspotController::deviceAdded(const QList<WirelessDevice*> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void dde::network::HotspotController::deviceRemove(const QList<WirelessDevice*> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void dde::network::HotspotController::enableHotspotSwitch(const bool & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN3dde7network11HotspotItemE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::HotspotItem::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network11HotspotItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::HotspotItem"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<HotspotItem, qt_meta_tag_ZN3dde7network11HotspotItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::HotspotItem::staticMetaObject = { {
    QMetaObject::SuperData::link<ControllItems::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network11HotspotItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network11HotspotItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network11HotspotItemE_t>.metaTypes,
    nullptr
} };

void dde::network::HotspotItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<HotspotItem *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *dde::network::HotspotItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::HotspotItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network11HotspotItemE_t>.strings))
        return static_cast<void*>(this);
    return ControllItems::qt_metacast(_clname);
}

int dde::network::HotspotItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ControllItems::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
