/****************************************************************************
** Meta object code from reading C++ file 'wirelessdevice.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../wirelessdevice.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'wirelessdevice.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3dde7network14WirelessDeviceE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::WirelessDevice::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network14WirelessDeviceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::WirelessDevice",
        "networkAdded",
        "",
        "QList<AccessPoints*>",
        "networkRemoved",
        "connectionFailed",
        "const AccessPoints*",
        "connectionSuccess",
        "hotspotEnableChanged",
        "accessPointInfoChanged",
        "wirelessConnectionAdded",
        "QList<WirelessConnection*>",
        "wirelessConnectionRemoved",
        "wirelessConnectionPropertyChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'networkAdded'
        QtMocHelpers::SignalData<void(const QList<AccessPoints*> &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'networkRemoved'
        QtMocHelpers::SignalData<void(const QList<AccessPoints*> &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'connectionFailed'
        QtMocHelpers::SignalData<void(const AccessPoints *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Signal 'connectionSuccess'
        QtMocHelpers::SignalData<void(const AccessPoints *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Signal 'hotspotEnableChanged'
        QtMocHelpers::SignalData<void(const bool &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'accessPointInfoChanged'
        QtMocHelpers::SignalData<void(const QList<AccessPoints*> &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'wirelessConnectionAdded'
        QtMocHelpers::SignalData<void(const QList<WirelessConnection*> &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 2 },
        }}),
        // Signal 'wirelessConnectionRemoved'
        QtMocHelpers::SignalData<void(const QList<WirelessConnection*> &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 2 },
        }}),
        // Signal 'wirelessConnectionPropertyChanged'
        QtMocHelpers::SignalData<void(const QList<WirelessConnection*> &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WirelessDevice, qt_meta_tag_ZN3dde7network14WirelessDeviceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::WirelessDevice::staticMetaObject = { {
    QMetaObject::SuperData::link<NetworkDeviceBase::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network14WirelessDeviceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network14WirelessDeviceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network14WirelessDeviceE_t>.metaTypes,
    nullptr
} };

void dde::network::WirelessDevice::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WirelessDevice *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->networkAdded((*reinterpret_cast<std::add_pointer_t<QList<AccessPoints*>>>(_a[1]))); break;
        case 1: _t->networkRemoved((*reinterpret_cast<std::add_pointer_t<QList<AccessPoints*>>>(_a[1]))); break;
        case 2: _t->connectionFailed((*reinterpret_cast<std::add_pointer_t<const AccessPoints*>>(_a[1]))); break;
        case 3: _t->connectionSuccess((*reinterpret_cast<std::add_pointer_t<const AccessPoints*>>(_a[1]))); break;
        case 4: _t->hotspotEnableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->accessPointInfoChanged((*reinterpret_cast<std::add_pointer_t<QList<AccessPoints*>>>(_a[1]))); break;
        case 6: _t->wirelessConnectionAdded((*reinterpret_cast<std::add_pointer_t<QList<WirelessConnection*>>>(_a[1]))); break;
        case 7: _t->wirelessConnectionRemoved((*reinterpret_cast<std::add_pointer_t<QList<WirelessConnection*>>>(_a[1]))); break;
        case 8: _t->wirelessConnectionPropertyChanged((*reinterpret_cast<std::add_pointer_t<QList<WirelessConnection*>>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<AccessPoints*> >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<AccessPoints*> >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<AccessPoints*> >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<WirelessConnection*> >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<WirelessConnection*> >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<WirelessConnection*> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WirelessDevice::*)(const QList<AccessPoints*> & )>(_a, &WirelessDevice::networkAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (WirelessDevice::*)(const QList<AccessPoints*> & )>(_a, &WirelessDevice::networkRemoved, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (WirelessDevice::*)(const AccessPoints * )>(_a, &WirelessDevice::connectionFailed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (WirelessDevice::*)(const AccessPoints * )>(_a, &WirelessDevice::connectionSuccess, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (WirelessDevice::*)(const bool & )>(_a, &WirelessDevice::hotspotEnableChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (WirelessDevice::*)(const QList<AccessPoints*> & )>(_a, &WirelessDevice::accessPointInfoChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (WirelessDevice::*)(const QList<WirelessConnection*> & )>(_a, &WirelessDevice::wirelessConnectionAdded, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (WirelessDevice::*)(const QList<WirelessConnection*> & )>(_a, &WirelessDevice::wirelessConnectionRemoved, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (WirelessDevice::*)(const QList<WirelessConnection*> & )>(_a, &WirelessDevice::wirelessConnectionPropertyChanged, 8))
            return;
    }
}

const QMetaObject *dde::network::WirelessDevice::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::WirelessDevice::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network14WirelessDeviceE_t>.strings))
        return static_cast<void*>(this);
    return NetworkDeviceBase::qt_metacast(_clname);
}

int dde::network::WirelessDevice::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NetworkDeviceBase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void dde::network::WirelessDevice::networkAdded(const QList<AccessPoints*> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void dde::network::WirelessDevice::networkRemoved(const QList<AccessPoints*> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void dde::network::WirelessDevice::connectionFailed(const AccessPoints * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void dde::network::WirelessDevice::connectionSuccess(const AccessPoints * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void dde::network::WirelessDevice::hotspotEnableChanged(const bool & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void dde::network::WirelessDevice::accessPointInfoChanged(const QList<AccessPoints*> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void dde::network::WirelessDevice::wirelessConnectionAdded(const QList<WirelessConnection*> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void dde::network::WirelessDevice::wirelessConnectionRemoved(const QList<WirelessConnection*> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void dde::network::WirelessDevice::wirelessConnectionPropertyChanged(const QList<WirelessConnection*> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN3dde7network12AccessPointsE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::AccessPoints::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network12AccessPointsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::AccessPoints",
        "strengthChanged",
        "",
        "connectionStatusChanged",
        "ConnectionStatus",
        "securedChanged",
        "ssid",
        "strength",
        "secured",
        "securedInEap",
        "frequency",
        "path",
        "devicePath",
        "connected"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'strengthChanged'
        QtMocHelpers::SignalData<void(const int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'connectionStatusChanged'
        QtMocHelpers::SignalData<void(ConnectionStatus)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Signal 'securedChanged'
        QtMocHelpers::SignalData<void(bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'ssid'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'strength'
        QtMocHelpers::PropertyData<int>(7, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'secured'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'securedInEap'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'frequency'
        QtMocHelpers::PropertyData<int>(10, QMetaType::Int, QMC::DefaultPropertyFlags),
        // property 'path'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'devicePath'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'connected'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AccessPoints, qt_meta_tag_ZN3dde7network12AccessPointsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::AccessPoints::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network12AccessPointsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network12AccessPointsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network12AccessPointsE_t>.metaTypes,
    nullptr
} };

void dde::network::AccessPoints::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AccessPoints *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->strengthChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->connectionStatusChanged((*reinterpret_cast<std::add_pointer_t<ConnectionStatus>>(_a[1]))); break;
        case 2: _t->securedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AccessPoints::*)(const int )>(_a, &AccessPoints::strengthChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccessPoints::*)(ConnectionStatus )>(_a, &AccessPoints::connectionStatusChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AccessPoints::*)(bool )>(_a, &AccessPoints::securedChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->ssid(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->strength(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->secured(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->securedInEap(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->frequency(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->path(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->devicePath(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->connected(); break;
        default: break;
        }
    }
}

const QMetaObject *dde::network::AccessPoints::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::AccessPoints::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network12AccessPointsE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dde::network::AccessPoints::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void dde::network::AccessPoints::strengthChanged(const int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void dde::network::AccessPoints::connectionStatusChanged(ConnectionStatus _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void dde::network::AccessPoints::securedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN3dde7network18WirelessConnectionE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::WirelessConnection::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network18WirelessConnectionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::WirelessConnection"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WirelessConnection, qt_meta_tag_ZN3dde7network18WirelessConnectionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::WirelessConnection::staticMetaObject = { {
    QMetaObject::SuperData::link<ControllItems::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network18WirelessConnectionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network18WirelessConnectionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network18WirelessConnectionE_t>.metaTypes,
    nullptr
} };

void dde::network::WirelessConnection::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WirelessConnection *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *dde::network::WirelessConnection::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::WirelessConnection::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network18WirelessConnectionE_t>.strings))
        return static_cast<void*>(this);
    return ControllItems::qt_metacast(_clname);
}

int dde::network::WirelessConnection::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ControllItems::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
