/****************************************************************************
** Meta object code from reading C++ file 'netmanagerthreadprivate.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../net-view/operation/private/netmanagerthreadprivate.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'netmanagerthreadprivate.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3dde7network23NetManagerThreadPrivateE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::NetManagerThreadPrivate::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network23NetManagerThreadPrivateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::NetManagerThreadPrivate",
        "request",
        "",
        "NetManager::CmdType",
        "cmd",
        "id",
        "QVariantMap",
        "param",
        "requestInputPassword",
        "dev",
        "itemAdded",
        "parentID",
        "NetItemPrivate*",
        "item",
        "itemRemoved",
        "dataChanged",
        "dataType",
        "QVariant",
        "value",
        "networkNotify",
        "inAppName",
        "replacesId",
        "appIcon",
        "summary",
        "body",
        "actions",
        "hints",
        "expireTimeout",
        "toControlCenter",
        "netCheckAvailableChanged",
        "netCheckAvailable",
        "setDeviceEnabled",
        "enabled",
        "requestScan",
        "disconnectDevice",
        "disconnectConnection",
        "path",
        "connectHidden",
        "ssid",
        "connectWired",
        "connectWireless",
        "connectHotspot",
        "connect",
        "gotoControlCenter",
        "page",
        "gotoSecurityTools",
        "userCancelRequest",
        "retranslate",
        "locale",
        "sendNotify",
        "onNetCheckPropertiesChanged",
        "properties",
        "onAirplaneModeEnabledPropertiesChanged",
        "onAirplaneModePropertiesChanged",
        "connectOrInfo",
        "NetType::NetItemType",
        "type",
        "getConnectInfo",
        "setConnectInfo",
        "deleteConnect",
        "uuid",
        "importConnect",
        "file",
        "exportConnect",
        "showPage",
        "doInit",
        "clearData",
        "doSetDeviceEnabled",
        "doRequestScan",
        "doDisconnectDevice",
        "doDisconnectConnection",
        "doConnectHidden",
        "doConnectWired",
        "doConnectWireless",
        "doConnectHotspot",
        "doGotoControlCenter",
        "doGotoSecurityTools",
        "doUserCancelRequest",
        "doRetranslate",
        "updateNetCheckAvailabled",
        "QDBusVariant",
        "availabled",
        "updateAirplaneModeEnabled",
        "updateAirplaneModeEnabledable",
        "enabledable",
        "supportAirplaneMode",
        "doConnectOrInfo",
        "doGetConnectInfo",
        "doSetConnectInfo",
        "doDeleteConnect",
        "changeVpnId",
        "doImportConnect",
        "doExportConnect",
        "doSetSystemProxy",
        "doSetAppProxy",
        "clearShowPageCmd",
        "toShowPage",
        "doShowPage",
        "sendRequest",
        "onDeviceAdded",
        "QList<NetworkDeviceBase*>",
        "devices",
        "onDeviceRemoved",
        "onConnectivityChanged",
        "updateDSLEnabledable",
        "onConnectionAdded",
        "QList<WiredConnection*>",
        "conns",
        "onConnectionRemoved",
        "addConnection",
        "const NetworkDeviceBase*",
        "device",
        "onConnectionChanged",
        "onNetworkAdded",
        "QList<AccessPoints*>",
        "aps",
        "onNetworkRemoved",
        "addNetwork",
        "onNameChanged",
        "name",
        "onDevEnabledChanged",
        "onDevAvailableChanged",
        "available",
        "onActiveConnectionChanged",
        "onIpV4Changed",
        "onDeviceStatusChanged",
        "onHotspotEnabledChanged",
        "onAvailableConnectionsChanged",
        "onStrengthChanged",
        "strength",
        "onAPStatusChanged",
        "ConnectionStatus",
        "status",
        "onAPSecureChanged",
        "secure",
        "onVPNAdded",
        "QList<VPNItem*>",
        "vpns",
        "onVPNRemoved",
        "onVPNEnableChanged",
        "enable",
        "onVpnActiveConnectionChanged",
        "onVPNConnectionChanged",
        "onSystemProxyExistChanged",
        "exist",
        "onLastProxyMethodChanged",
        "ProxyMethod",
        "method",
        "onSystemProxyMethodChanged",
        "onSystemAutoProxyChanged",
        "url",
        "onSystemManualProxyChanged",
        "onAppProxyEnableChanged",
        "onAppProxyChanged",
        "updateHotspotEnabledChanged",
        "onHotspotEnabledableChanged",
        "onHotspotConfigChanged",
        "config",
        "onHotspotOptionalDeviceChanged",
        "optionalDevice",
        "onHotspotShareDeviceChanged",
        "shareDevice",
        "getAirplaneModeEnabled",
        "setAirplaneModeEnabled",
        "onDSLAdded",
        "QList<DSLItem*>",
        "dsls",
        "onDSLRemoved",
        "onDslActiveConnectionChanged",
        "updateDetails",
        "updateAutoScan",
        "doAutoScan",
        "addDeviceNotify",
        "onNotifyDeviceStatusChanged",
        "NetworkManager::Device::State",
        "newState",
        "oldState",
        "NetworkManager::Device::StateChangeReason",
        "reason",
        "sendNetworkNotify",
        "NetworkNotifyType",
        "updateHiddenNetworkConfig",
        "WirelessDevice*",
        "wireless",
        "needSetPassword",
        "AccessPoints*",
        "accessPoint",
        "handleAccessPointSecure",
        "handle8021xAccessPoint",
        "ap",
        "hidden",
        "onPrepareForSleep",
        "state"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'request'
        QtMocHelpers::SignalData<void(NetManager::CmdType, const QString &, const QVariantMap &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Signal 'requestInputPassword'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QVariantMap &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Signal 'itemAdded'
        QtMocHelpers::SignalData<void(const QString &, NetItemPrivate *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 }, { 0x80000000 | 12, 13 },
        }}),
        // Signal 'itemRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'dataChanged'
        QtMocHelpers::SignalData<void(int, const QString &, const QVariant &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 }, { QMetaType::QString, 5 }, { 0x80000000 | 17, 18 },
        }}),
        // Signal 'networkNotify'
        QtMocHelpers::SignalData<void(const QString &, int, const QString &, const QString &, const QString &, const QStringList &, const QVariantMap &, int)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 }, { QMetaType::Int, 21 }, { QMetaType::QString, 22 }, { QMetaType::QString, 23 },
            { QMetaType::QString, 24 }, { QMetaType::QStringList, 25 }, { 0x80000000 | 6, 26 }, { QMetaType::Int, 27 },
        }}),
        // Signal 'toControlCenter'
        QtMocHelpers::SignalData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'netCheckAvailableChanged'
        QtMocHelpers::SignalData<void(const bool &)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 30 },
        }}),
        // Slot 'setDeviceEnabled'
        QtMocHelpers::SlotData<void(const QString &, bool)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::Bool, 32 },
        }}),
        // Slot 'requestScan'
        QtMocHelpers::SlotData<void(const QString &)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'disconnectDevice'
        QtMocHelpers::SlotData<void(const QString &)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'disconnectConnection'
        QtMocHelpers::SlotData<void(const QString &)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 36 },
        }}),
        // Slot 'connectHidden'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 38 },
        }}),
        // Slot 'connectWired'
        QtMocHelpers::SlotData<void(const QString &, const QVariantMap &)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'connectWireless'
        QtMocHelpers::SlotData<void(const QString &, const QVariantMap &)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'connectHotspot'
        QtMocHelpers::SlotData<void(const QString &, const QVariantMap &, bool)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { QMetaType::Bool, 42 },
        }}),
        // Slot 'gotoControlCenter'
        QtMocHelpers::SlotData<void(const QString &)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 44 },
        }}),
        // Slot 'gotoSecurityTools'
        QtMocHelpers::SlotData<void(const QString &)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 44 },
        }}),
        // Slot 'userCancelRequest'
        QtMocHelpers::SlotData<void(const QString &)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'retranslate'
        QtMocHelpers::SlotData<void(const QString &)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 48 },
        }}),
        // Slot 'sendNotify'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &, const QString &, int, const QStringList &, const QVariantMap &, int)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 22 }, { QMetaType::QString, 24 }, { QMetaType::QString, 23 }, { QMetaType::QString, 20 },
            { QMetaType::Int, 21 }, { QMetaType::QStringList, 25 }, { 0x80000000 | 6, 26 }, { QMetaType::Int, 27 },
        }}),
        // Slot 'sendNotify'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &, const QString &, int, const QStringList &, const QVariantMap &)>(49, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 22 }, { QMetaType::QString, 24 }, { QMetaType::QString, 23 }, { QMetaType::QString, 20 },
            { QMetaType::Int, 21 }, { QMetaType::QStringList, 25 }, { 0x80000000 | 6, 26 },
        }}),
        // Slot 'sendNotify'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &, const QString &, int, const QStringList &)>(49, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 22 }, { QMetaType::QString, 24 }, { QMetaType::QString, 23 }, { QMetaType::QString, 20 },
            { QMetaType::Int, 21 }, { QMetaType::QStringList, 25 },
        }}),
        // Slot 'sendNotify'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &, const QString &, int)>(49, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 22 }, { QMetaType::QString, 24 }, { QMetaType::QString, 23 }, { QMetaType::QString, 20 },
            { QMetaType::Int, 21 },
        }}),
        // Slot 'sendNotify'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &, const QString &)>(49, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 22 }, { QMetaType::QString, 24 }, { QMetaType::QString, 23 }, { QMetaType::QString, 20 },
        }}),
        // Slot 'sendNotify'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &)>(49, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 22 }, { QMetaType::QString, 24 }, { QMetaType::QString, 23 },
        }}),
        // Slot 'sendNotify'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(49, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 22 }, { QMetaType::QString, 24 },
        }}),
        // Slot 'onNetCheckPropertiesChanged'
        QtMocHelpers::SlotData<void(QString, QVariantMap, QStringList)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { 0x80000000 | 6, 51 }, { QMetaType::QStringList, 2 },
        }}),
        // Slot 'onAirplaneModeEnabledPropertiesChanged'
        QtMocHelpers::SlotData<void(const QString &, const QVariantMap &, const QStringList &)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { 0x80000000 | 6, 51 }, { QMetaType::QStringList, 2 },
        }}),
        // Slot 'onAirplaneModePropertiesChanged'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(53, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 51 },
        }}),
        // Slot 'connectOrInfo'
        QtMocHelpers::SlotData<void(const QString &, NetType::NetItemType, const QVariantMap &)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 55, 56 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'getConnectInfo'
        QtMocHelpers::SlotData<void(const QString &, NetType::NetItemType, const QVariantMap &)>(57, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 55, 56 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'setConnectInfo'
        QtMocHelpers::SlotData<void(const QString &, NetType::NetItemType, const QVariantMap &)>(58, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 55, 56 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'deleteConnect'
        QtMocHelpers::SlotData<void(const QString &)>(59, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 60 },
        }}),
        // Slot 'importConnect'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(61, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 62 },
        }}),
        // Slot 'exportConnect'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(63, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 62 },
        }}),
        // Slot 'showPage'
        QtMocHelpers::SlotData<void(const QString &)>(64, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'doInit'
        QtMocHelpers::SlotData<void()>(65, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'clearData'
        QtMocHelpers::SlotData<void()>(66, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'doSetDeviceEnabled'
        QtMocHelpers::SlotData<void(const QString &, bool)>(67, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::Bool, 32 },
        }}),
        // Slot 'doRequestScan'
        QtMocHelpers::SlotData<void(const QString &)>(68, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'doDisconnectDevice'
        QtMocHelpers::SlotData<void(const QString &)>(69, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'doDisconnectConnection'
        QtMocHelpers::SlotData<void(const QString &)>(70, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 36 },
        }}),
        // Slot 'doConnectHidden'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(71, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 38 },
        }}),
        // Slot 'doConnectWired'
        QtMocHelpers::SlotData<void(const QString &, const QVariantMap &)>(72, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'doConnectWireless'
        QtMocHelpers::SlotData<void(const QString &, const QVariantMap &)>(73, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'doConnectHotspot'
        QtMocHelpers::SlotData<void(const QString &, const QVariantMap &, bool)>(74, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 }, { QMetaType::Bool, 42 },
        }}),
        // Slot 'doGotoControlCenter'
        QtMocHelpers::SlotData<void(const QString &)>(75, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 44 },
        }}),
        // Slot 'doGotoSecurityTools'
        QtMocHelpers::SlotData<void(const QString &)>(76, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 44 },
        }}),
        // Slot 'doUserCancelRequest'
        QtMocHelpers::SlotData<void(const QString &)>(77, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'doRetranslate'
        QtMocHelpers::SlotData<void(const QString &)>(78, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 48 },
        }}),
        // Slot 'updateNetCheckAvailabled'
        QtMocHelpers::SlotData<void(const QDBusVariant &)>(79, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 80, 81 },
        }}),
        // Slot 'updateAirplaneModeEnabled'
        QtMocHelpers::SlotData<void(const QDBusVariant &)>(82, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 80, 32 },
        }}),
        // Slot 'updateAirplaneModeEnabledable'
        QtMocHelpers::SlotData<void(const QDBusVariant &)>(83, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 80, 84 },
        }}),
        // Slot 'supportAirplaneMode'
        QtMocHelpers::SlotData<bool() const>(85, 2, QMC::AccessProtected, QMetaType::Bool),
        // Slot 'doConnectOrInfo'
        QtMocHelpers::SlotData<void(const QString &, NetType::NetItemType, const QVariantMap &)>(86, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 55, 56 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'doGetConnectInfo'
        QtMocHelpers::SlotData<void(const QString &, NetType::NetItemType, const QVariantMap &)>(87, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 55, 56 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'doSetConnectInfo'
        QtMocHelpers::SlotData<void(const QString &, NetType::NetItemType, const QVariantMap &)>(88, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 55, 56 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'doDeleteConnect'
        QtMocHelpers::SlotData<void(const QString &)>(89, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 60 },
        }}),
        // Slot 'changeVpnId'
        QtMocHelpers::SlotData<void()>(90, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'doImportConnect'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(91, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 62 },
        }}),
        // Slot 'doExportConnect'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(92, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 62 },
        }}),
        // Slot 'doSetSystemProxy'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(93, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'doSetAppProxy'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(94, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'clearShowPageCmd'
        QtMocHelpers::SlotData<void()>(95, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'toShowPage'
        QtMocHelpers::SlotData<bool()>(96, 2, QMC::AccessProtected, QMetaType::Bool),
        // Slot 'doShowPage'
        QtMocHelpers::SlotData<void(const QString &)>(97, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'sendRequest'
        QtMocHelpers::SlotData<void(NetManager::CmdType, const QString &, const QVariantMap &)>(98, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'sendRequest'
        QtMocHelpers::SlotData<void(NetManager::CmdType, const QString &)>(98, 2, QMC::AccessProtected | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 },
        }}),
        // Slot 'onDeviceAdded'
        QtMocHelpers::SlotData<void(QList<NetworkDeviceBase*>)>(99, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 100, 101 },
        }}),
        // Slot 'onDeviceRemoved'
        QtMocHelpers::SlotData<void(QList<NetworkDeviceBase*>)>(102, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 100, 101 },
        }}),
        // Slot 'onConnectivityChanged'
        QtMocHelpers::SlotData<void()>(103, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'updateDSLEnabledable'
        QtMocHelpers::SlotData<void()>(104, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onConnectionAdded'
        QtMocHelpers::SlotData<void(const QList<WiredConnection*> &)>(105, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 106, 107 },
        }}),
        // Slot 'onConnectionRemoved'
        QtMocHelpers::SlotData<void(const QList<WiredConnection*> &)>(108, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 106, 107 },
        }}),
        // Slot 'addConnection'
        QtMocHelpers::SlotData<void(const NetworkDeviceBase *, const QList<WiredConnection*> &)>(109, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 110, 111 }, { 0x80000000 | 106, 107 },
        }}),
        // Slot 'onConnectionChanged'
        QtMocHelpers::SlotData<void()>(112, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onNetworkAdded'
        QtMocHelpers::SlotData<void(const QList<AccessPoints*> &)>(113, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 114, 115 },
        }}),
        // Slot 'onNetworkRemoved'
        QtMocHelpers::SlotData<void(const QList<AccessPoints*> &)>(116, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 114, 115 },
        }}),
        // Slot 'addNetwork'
        QtMocHelpers::SlotData<void(const NetworkDeviceBase *, QList<AccessPoints*>)>(117, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 110, 111 }, { 0x80000000 | 114, 115 },
        }}),
        // Slot 'onNameChanged'
        QtMocHelpers::SlotData<void(const QString &)>(118, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 119 },
        }}),
        // Slot 'onDevEnabledChanged'
        QtMocHelpers::SlotData<void(const bool)>(120, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 32 },
        }}),
        // Slot 'onDevAvailableChanged'
        QtMocHelpers::SlotData<void(const bool)>(121, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 122 },
        }}),
        // Slot 'onActiveConnectionChanged'
        QtMocHelpers::SlotData<void()>(123, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onIpV4Changed'
        QtMocHelpers::SlotData<void()>(124, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onDeviceStatusChanged'
        QtMocHelpers::SlotData<void()>(125, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onHotspotEnabledChanged'
        QtMocHelpers::SlotData<void()>(126, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onAvailableConnectionsChanged'
        QtMocHelpers::SlotData<void()>(127, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onStrengthChanged'
        QtMocHelpers::SlotData<void(int)>(128, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 129 },
        }}),
        // Slot 'onAPStatusChanged'
        QtMocHelpers::SlotData<void(ConnectionStatus)>(130, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 131, 132 },
        }}),
        // Slot 'onAPSecureChanged'
        QtMocHelpers::SlotData<void(bool)>(133, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 134 },
        }}),
        // Slot 'onVPNAdded'
        QtMocHelpers::SlotData<void(const QList<VPNItem*> &)>(135, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 136, 137 },
        }}),
        // Slot 'onVPNRemoved'
        QtMocHelpers::SlotData<void(const QList<VPNItem*> &)>(138, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 136, 137 },
        }}),
        // Slot 'onVPNEnableChanged'
        QtMocHelpers::SlotData<void(const bool)>(139, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 140 },
        }}),
        // Slot 'onVpnActiveConnectionChanged'
        QtMocHelpers::SlotData<void()>(141, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onVPNConnectionChanged'
        QtMocHelpers::SlotData<void()>(142, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onSystemProxyExistChanged'
        QtMocHelpers::SlotData<void(bool)>(143, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 144 },
        }}),
        // Slot 'onLastProxyMethodChanged'
        QtMocHelpers::SlotData<void(const ProxyMethod &)>(145, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 146, 147 },
        }}),
        // Slot 'onSystemProxyMethodChanged'
        QtMocHelpers::SlotData<void(const ProxyMethod &)>(148, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 146, 147 },
        }}),
        // Slot 'onSystemAutoProxyChanged'
        QtMocHelpers::SlotData<void(const QString &)>(149, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 150 },
        }}),
        // Slot 'onSystemManualProxyChanged'
        QtMocHelpers::SlotData<void()>(151, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onAppProxyEnableChanged'
        QtMocHelpers::SlotData<void(bool)>(152, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 32 },
        }}),
        // Slot 'onAppProxyChanged'
        QtMocHelpers::SlotData<void()>(153, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'updateHotspotEnabledChanged'
        QtMocHelpers::SlotData<void(const bool)>(154, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 32 },
        }}),
        // Slot 'onHotspotEnabledableChanged'
        QtMocHelpers::SlotData<void(const bool)>(155, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 84 },
        }}),
        // Slot 'onHotspotConfigChanged'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(156, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 6, 157 },
        }}),
        // Slot 'onHotspotOptionalDeviceChanged'
        QtMocHelpers::SlotData<void(const QStringList &)>(158, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QStringList, 159 },
        }}),
        // Slot 'onHotspotShareDeviceChanged'
        QtMocHelpers::SlotData<void(const QStringList &)>(160, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QStringList, 161 },
        }}),
        // Slot 'getAirplaneModeEnabled'
        QtMocHelpers::SlotData<void()>(162, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'setAirplaneModeEnabled'
        QtMocHelpers::SlotData<void(bool)>(163, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 32 },
        }}),
        // Slot 'onDSLAdded'
        QtMocHelpers::SlotData<void(const QList<DSLItem*> &)>(164, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 165, 166 },
        }}),
        // Slot 'onDSLRemoved'
        QtMocHelpers::SlotData<void(const QList<DSLItem*> &)>(167, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 165, 166 },
        }}),
        // Slot 'onDslActiveConnectionChanged'
        QtMocHelpers::SlotData<void()>(168, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'updateDetails'
        QtMocHelpers::SlotData<void()>(169, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'updateAutoScan'
        QtMocHelpers::SlotData<void()>(170, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'doAutoScan'
        QtMocHelpers::SlotData<void()>(171, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'addDeviceNotify'
        QtMocHelpers::SlotData<void(const QString &)>(172, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 36 },
        }}),
        // Slot 'onNotifyDeviceStatusChanged'
        QtMocHelpers::SlotData<void(NetworkManager::Device::State, NetworkManager::Device::State, NetworkManager::Device::StateChangeReason)>(173, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 174, 175 }, { 0x80000000 | 174, 176 }, { 0x80000000 | 177, 178 },
        }}),
        // Slot 'sendNetworkNotify'
        QtMocHelpers::SlotData<void(NetworkNotifyType, const QString &)>(179, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 180, 56 }, { QMetaType::QString, 119 },
        }}),
        // Slot 'updateHiddenNetworkConfig'
        QtMocHelpers::SlotData<void(WirelessDevice *)>(181, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 182, 183 },
        }}),
        // Slot 'needSetPassword'
        QtMocHelpers::SlotData<bool(AccessPoints *) const>(184, 2, QMC::AccessProtected, QMetaType::Bool, {{
            { 0x80000000 | 185, 186 },
        }}),
        // Slot 'handleAccessPointSecure'
        QtMocHelpers::SlotData<void(AccessPoints *)>(187, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 185, 186 },
        }}),
        // Slot 'handle8021xAccessPoint'
        QtMocHelpers::SlotData<bool(AccessPoints *, bool)>(188, 2, QMC::AccessProtected, QMetaType::Bool, {{
            { 0x80000000 | 185, 189 }, { QMetaType::Bool, 190 },
        }}),
        // Slot 'onPrepareForSleep'
        QtMocHelpers::SlotData<void(bool)>(191, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 192 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NetManagerThreadPrivate, qt_meta_tag_ZN3dde7network23NetManagerThreadPrivateE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::NetManagerThreadPrivate::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network23NetManagerThreadPrivateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network23NetManagerThreadPrivateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network23NetManagerThreadPrivateE_t>.metaTypes,
    nullptr
} };

void dde::network::NetManagerThreadPrivate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NetManagerThreadPrivate *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->request((*reinterpret_cast<std::add_pointer_t<NetManager::CmdType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[3]))); break;
        case 1: _t->requestInputPassword((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[3]))); break;
        case 2: _t->itemAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<NetItemPrivate*>>(_a[2]))); break;
        case 3: _t->itemRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->dataChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3]))); break;
        case 5: _t->networkNotify((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[8]))); break;
        case 6: _t->toControlCenter(); break;
        case 7: _t->netCheckAvailableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->setDeviceEnabled((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 9: _t->requestScan((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->disconnectDevice((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->disconnectConnection((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->connectHidden((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 13: _t->connectWired((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2]))); break;
        case 14: _t->connectWireless((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2]))); break;
        case 15: _t->connectHotspot((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 16: _t->gotoControlCenter((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->gotoSecurityTools((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 18: _t->userCancelRequest((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 19: _t->retranslate((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 20: _t->sendNotify((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[8]))); break;
        case 21: _t->sendNotify((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[7]))); break;
        case 22: _t->sendNotify((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[6]))); break;
        case 23: _t->sendNotify((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5]))); break;
        case 24: _t->sendNotify((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 25: _t->sendNotify((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 26: _t->sendNotify((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 27: _t->onNetCheckPropertiesChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3]))); break;
        case 28: _t->onAirplaneModeEnabledPropertiesChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3]))); break;
        case 29: _t->onAirplaneModePropertiesChanged((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 30: _t->connectOrInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<NetType::NetItemType>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[3]))); break;
        case 31: _t->getConnectInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<NetType::NetItemType>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[3]))); break;
        case 32: _t->setConnectInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<NetType::NetItemType>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[3]))); break;
        case 33: _t->deleteConnect((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 34: _t->importConnect((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 35: _t->exportConnect((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 36: _t->showPage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 37: _t->doInit(); break;
        case 38: _t->clearData(); break;
        case 39: _t->doSetDeviceEnabled((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 40: _t->doRequestScan((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 41: _t->doDisconnectDevice((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 42: _t->doDisconnectConnection((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 43: _t->doConnectHidden((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 44: _t->doConnectWired((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2]))); break;
        case 45: _t->doConnectWireless((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2]))); break;
        case 46: _t->doConnectHotspot((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 47: _t->doGotoControlCenter((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 48: _t->doGotoSecurityTools((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 49: _t->doUserCancelRequest((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 50: _t->doRetranslate((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 51: _t->updateNetCheckAvailabled((*reinterpret_cast<std::add_pointer_t<QDBusVariant>>(_a[1]))); break;
        case 52: _t->updateAirplaneModeEnabled((*reinterpret_cast<std::add_pointer_t<QDBusVariant>>(_a[1]))); break;
        case 53: _t->updateAirplaneModeEnabledable((*reinterpret_cast<std::add_pointer_t<QDBusVariant>>(_a[1]))); break;
        case 54: { bool _r = _t->supportAirplaneMode();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 55: _t->doConnectOrInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<NetType::NetItemType>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[3]))); break;
        case 56: _t->doGetConnectInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<NetType::NetItemType>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[3]))); break;
        case 57: _t->doSetConnectInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<NetType::NetItemType>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[3]))); break;
        case 58: _t->doDeleteConnect((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 59: _t->changeVpnId(); break;
        case 60: _t->doImportConnect((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 61: _t->doExportConnect((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 62: _t->doSetSystemProxy((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 63: _t->doSetAppProxy((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 64: _t->clearShowPageCmd(); break;
        case 65: { bool _r = _t->toShowPage();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 66: _t->doShowPage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 67: _t->sendRequest((*reinterpret_cast<std::add_pointer_t<NetManager::CmdType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[3]))); break;
        case 68: _t->sendRequest((*reinterpret_cast<std::add_pointer_t<NetManager::CmdType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 69: _t->onDeviceAdded((*reinterpret_cast<std::add_pointer_t<QList<NetworkDeviceBase*>>>(_a[1]))); break;
        case 70: _t->onDeviceRemoved((*reinterpret_cast<std::add_pointer_t<QList<NetworkDeviceBase*>>>(_a[1]))); break;
        case 71: _t->onConnectivityChanged(); break;
        case 72: _t->updateDSLEnabledable(); break;
        case 73: _t->onConnectionAdded((*reinterpret_cast<std::add_pointer_t<QList<WiredConnection*>>>(_a[1]))); break;
        case 74: _t->onConnectionRemoved((*reinterpret_cast<std::add_pointer_t<QList<WiredConnection*>>>(_a[1]))); break;
        case 75: _t->addConnection((*reinterpret_cast<std::add_pointer_t<const NetworkDeviceBase*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<WiredConnection*>>>(_a[2]))); break;
        case 76: _t->onConnectionChanged(); break;
        case 77: _t->onNetworkAdded((*reinterpret_cast<std::add_pointer_t<QList<AccessPoints*>>>(_a[1]))); break;
        case 78: _t->onNetworkRemoved((*reinterpret_cast<std::add_pointer_t<QList<AccessPoints*>>>(_a[1]))); break;
        case 79: _t->addNetwork((*reinterpret_cast<std::add_pointer_t<const NetworkDeviceBase*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<AccessPoints*>>>(_a[2]))); break;
        case 80: _t->onNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 81: _t->onDevEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 82: _t->onDevAvailableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 83: _t->onActiveConnectionChanged(); break;
        case 84: _t->onIpV4Changed(); break;
        case 85: _t->onDeviceStatusChanged(); break;
        case 86: _t->onHotspotEnabledChanged(); break;
        case 87: _t->onAvailableConnectionsChanged(); break;
        case 88: _t->onStrengthChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 89: _t->onAPStatusChanged((*reinterpret_cast<std::add_pointer_t<ConnectionStatus>>(_a[1]))); break;
        case 90: _t->onAPSecureChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 91: _t->onVPNAdded((*reinterpret_cast<std::add_pointer_t<QList<VPNItem*>>>(_a[1]))); break;
        case 92: _t->onVPNRemoved((*reinterpret_cast<std::add_pointer_t<QList<VPNItem*>>>(_a[1]))); break;
        case 93: _t->onVPNEnableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 94: _t->onVpnActiveConnectionChanged(); break;
        case 95: _t->onVPNConnectionChanged(); break;
        case 96: _t->onSystemProxyExistChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 97: _t->onLastProxyMethodChanged((*reinterpret_cast<std::add_pointer_t<ProxyMethod>>(_a[1]))); break;
        case 98: _t->onSystemProxyMethodChanged((*reinterpret_cast<std::add_pointer_t<ProxyMethod>>(_a[1]))); break;
        case 99: _t->onSystemAutoProxyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 100: _t->onSystemManualProxyChanged(); break;
        case 101: _t->onAppProxyEnableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 102: _t->onAppProxyChanged(); break;
        case 103: _t->updateHotspotEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 104: _t->onHotspotEnabledableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 105: _t->onHotspotConfigChanged((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 106: _t->onHotspotOptionalDeviceChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 107: _t->onHotspotShareDeviceChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 108: _t->getAirplaneModeEnabled(); break;
        case 109: _t->setAirplaneModeEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 110: _t->onDSLAdded((*reinterpret_cast<std::add_pointer_t<QList<DSLItem*>>>(_a[1]))); break;
        case 111: _t->onDSLRemoved((*reinterpret_cast<std::add_pointer_t<QList<DSLItem*>>>(_a[1]))); break;
        case 112: _t->onDslActiveConnectionChanged(); break;
        case 113: _t->updateDetails(); break;
        case 114: _t->updateAutoScan(); break;
        case 115: _t->doAutoScan(); break;
        case 116: _t->addDeviceNotify((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 117: _t->onNotifyDeviceStatusChanged((*reinterpret_cast<std::add_pointer_t<NetworkManager::Device::State>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<NetworkManager::Device::State>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<NetworkManager::Device::StateChangeReason>>(_a[3]))); break;
        case 118: _t->sendNetworkNotify((*reinterpret_cast<std::add_pointer_t<NetworkNotifyType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 119: _t->updateHiddenNetworkConfig((*reinterpret_cast<std::add_pointer_t<WirelessDevice*>>(_a[1]))); break;
        case 120: { bool _r = _t->needSetPassword((*reinterpret_cast<std::add_pointer_t<AccessPoints*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 121: _t->handleAccessPointSecure((*reinterpret_cast<std::add_pointer_t<AccessPoints*>>(_a[1]))); break;
        case 122: { bool _r = _t->handle8021xAccessPoint((*reinterpret_cast<std::add_pointer_t<AccessPoints*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 123: _t->onPrepareForSleep((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 51:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusVariant >(); break;
            }
            break;
        case 52:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusVariant >(); break;
            }
            break;
        case 53:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusVariant >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NetManagerThreadPrivate::*)(NetManager::CmdType , const QString & , const QVariantMap & )>(_a, &NetManagerThreadPrivate::request, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetManagerThreadPrivate::*)(const QString & , const QString & , const QVariantMap & )>(_a, &NetManagerThreadPrivate::requestInputPassword, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetManagerThreadPrivate::*)(const QString & , NetItemPrivate * )>(_a, &NetManagerThreadPrivate::itemAdded, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetManagerThreadPrivate::*)(const QString & )>(_a, &NetManagerThreadPrivate::itemRemoved, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetManagerThreadPrivate::*)(int , const QString & , const QVariant & )>(_a, &NetManagerThreadPrivate::dataChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetManagerThreadPrivate::*)(const QString & , int , const QString & , const QString & , const QString & , const QStringList & , const QVariantMap & , int )>(_a, &NetManagerThreadPrivate::networkNotify, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetManagerThreadPrivate::*)()>(_a, &NetManagerThreadPrivate::toControlCenter, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetManagerThreadPrivate::*)(const bool & )>(_a, &NetManagerThreadPrivate::netCheckAvailableChanged, 7))
            return;
    }
}

const QMetaObject *dde::network::NetManagerThreadPrivate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::NetManagerThreadPrivate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network23NetManagerThreadPrivateE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dde::network::NetManagerThreadPrivate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 124)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 124;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 124)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 124;
    }
    return _id;
}

// SIGNAL 0
void dde::network::NetManagerThreadPrivate::request(NetManager::CmdType _t1, const QString & _t2, const QVariantMap & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void dde::network::NetManagerThreadPrivate::requestInputPassword(const QString & _t1, const QString & _t2, const QVariantMap & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void dde::network::NetManagerThreadPrivate::itemAdded(const QString & _t1, NetItemPrivate * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void dde::network::NetManagerThreadPrivate::itemRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void dde::network::NetManagerThreadPrivate::dataChanged(int _t1, const QString & _t2, const QVariant & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2, _t3);
}

// SIGNAL 5
void dde::network::NetManagerThreadPrivate::networkNotify(const QString & _t1, int _t2, const QString & _t3, const QString & _t4, const QString & _t5, const QStringList & _t6, const QVariantMap & _t7, int _t8)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2, _t3, _t4, _t5, _t6, _t7, _t8);
}

// SIGNAL 6
void dde::network::NetManagerThreadPrivate::toControlCenter()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void dde::network::NetManagerThreadPrivate::netCheckAvailableChanged(const bool & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
QT_WARNING_POP
