/****************************************************************************
** Meta object code from reading C++ file 'networkinter.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../networkinter.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'networkinter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12NetworkInterE_t {};
} // unnamed namespace

template <> constexpr inline auto NetworkInter::qt_create_metaobjectdata<qt_meta_tag_ZN12NetworkInterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "NetworkInter",
        "AccessPointAdded",
        "",
        "in0",
        "in1",
        "AccessPointPropertiesChanged",
        "AccessPointRemoved",
        "ActiveConnectionInfoChanged",
        "DeviceEnabled",
        "IPConflict",
        "NeedSecrets",
        "NeedSecretsFinished",
        "ActiveConnectionsChanged",
        "value",
        "ConnectionsChanged",
        "ConnectivityChanged",
        "DevicesChanged",
        "NetworkingEnabledChanged",
        "StateChanged",
        "VpnEnabledChanged",
        "WirelessAccessPointsChanged",
        "ActivateAccessPoint",
        "QDBusPendingReply<QDBusObjectPath>",
        "QDBusObjectPath",
        "in2",
        "ActivateConnection",
        "CancelSecret",
        "QDBusPendingReply<>",
        "CancelSecretQueued",
        "CreateConnection",
        "CreateConnectionForAccessPoint",
        "DeactivateConnection",
        "DeactivateConnectionQueued",
        "DeleteConnection",
        "DeleteConnectionQueued",
        "DisableWirelessHotspotMode",
        "DisableWirelessHotspotModeQueued",
        "DisconnectDevice",
        "DisconnectDeviceQueued",
        "EditConnection",
        "EnableDevice",
        "EnableDeviceQueued",
        "EnableWirelessHotspotMode",
        "EnableWirelessHotspotModeQueued",
        "FeedSecret",
        "in3",
        "FeedSecretQueued",
        "GetAccessPoints",
        "QDBusPendingReply<QString>",
        "GetActiveConnectionInfo",
        "GetAutoProxy",
        "GetProxy",
        "QDBusPendingReply<QString,QString>",
        "QDBusReply<QString>",
        "QString&",
        "out1",
        "GetProxyIgnoreHosts",
        "GetProxyMethod",
        "GetSupportedConnectionTypes",
        "QDBusPendingReply<QStringList>",
        "GetWiredConnectionUuid",
        "IsDeviceEnabled",
        "QDBusPendingReply<bool>",
        "IsPasswordValid",
        "IsWirelessHotspotModeEnabled",
        "ListDeviceConnections",
        "QDBusPendingReply<QList<QDBusObjectPath>>",
        "RegisterSecretReceiver",
        "RegisterSecretReceiverQueued",
        "RequestIPConflictCheck",
        "RequestIPConflictCheckQueued",
        "RequestWirelessScan",
        "RequestWirelessScanQueued",
        "SetAutoProxy",
        "SetAutoProxyQueued",
        "SetDeviceManaged",
        "SetDeviceManagedQueued",
        "SetProxy",
        "SetProxyQueued",
        "SetProxyIgnoreHosts",
        "SetProxyIgnoreHostsQueued",
        "SetProxyMethod",
        "SetProxyMethodQueued",
        "CallQueued",
        "callName",
        "QList<QVariant>",
        "args",
        "ActiveConnections",
        "Connections",
        "Connectivity",
        "Devices",
        "NetworkingEnabled",
        "State",
        "VpnEnabled",
        "WirelessAccessPoints"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'AccessPointAdded'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'AccessPointPropertiesChanged'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'AccessPointRemoved'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'ActiveConnectionInfoChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'DeviceEnabled'
        QtMocHelpers::SignalData<void(const QString &, bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Bool, 4 },
        }}),
        // Signal 'IPConflict'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'NeedSecrets'
        QtMocHelpers::SignalData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'NeedSecretsFinished'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'ActiveConnectionsChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Signal 'ConnectionsChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Signal 'ConnectivityChanged'
        QtMocHelpers::SignalData<void(uint) const>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 13 },
        }}),
        // Signal 'DevicesChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Signal 'NetworkingEnabledChanged'
        QtMocHelpers::SignalData<void(bool) const>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Signal 'StateChanged'
        QtMocHelpers::SignalData<void(uint) const>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 13 },
        }}),
        // Signal 'VpnEnabledChanged'
        QtMocHelpers::SignalData<void(bool) const>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Signal 'WirelessAccessPointsChanged'
        QtMocHelpers::SignalData<void(const QString &) const>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'ActivateAccessPoint'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(const QString &, const QDBusObjectPath &, const QDBusObjectPath &)>(21, 2, QMC::AccessPublic, 0x80000000 | 22, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 23, 4 }, { 0x80000000 | 23, 24 },
        }}),
        // Slot 'ActivateConnection'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(const QString &, const QDBusObjectPath &)>(25, 2, QMC::AccessPublic, 0x80000000 | 22, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 23, 4 },
        }}),
        // Slot 'CancelSecret'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &)>(26, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 },
        }}),
        // Slot 'CancelSecretQueued'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 },
        }}),
        // Slot 'CreateConnection'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(const QString &, const QDBusObjectPath &)>(29, 2, QMC::AccessPublic, 0x80000000 | 22, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 23, 4 },
        }}),
        // Slot 'CreateConnectionForAccessPoint'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(const QDBusObjectPath &, const QDBusObjectPath &)>(30, 2, QMC::AccessPublic, 0x80000000 | 22, {{
            { 0x80000000 | 23, 3 }, { 0x80000000 | 23, 4 },
        }}),
        // Slot 'DeactivateConnection'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(31, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'DeactivateConnectionQueued'
        QtMocHelpers::SlotData<void(const QString &)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'DeleteConnection'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(33, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'DeleteConnectionQueued'
        QtMocHelpers::SlotData<void(const QString &)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'DisableWirelessHotspotMode'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &)>(35, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { 0x80000000 | 23, 3 },
        }}),
        // Slot 'DisableWirelessHotspotModeQueued'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 3 },
        }}),
        // Slot 'DisconnectDevice'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &)>(37, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { 0x80000000 | 23, 3 },
        }}),
        // Slot 'DisconnectDeviceQueued'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 3 },
        }}),
        // Slot 'EditConnection'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(const QString &, const QDBusObjectPath &)>(39, 2, QMC::AccessPublic, 0x80000000 | 22, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 23, 4 },
        }}),
        // Slot 'EnableDevice'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &, bool)>(40, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { 0x80000000 | 23, 3 }, { QMetaType::Bool, 4 },
        }}),
        // Slot 'EnableDeviceQueued'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, bool)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 3 }, { QMetaType::Bool, 4 },
        }}),
        // Slot 'EnableWirelessHotspotMode'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &)>(42, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { 0x80000000 | 23, 3 },
        }}),
        // Slot 'EnableWirelessHotspotModeQueued'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 3 },
        }}),
        // Slot 'FeedSecret'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &, const QString &, bool)>(44, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 }, { QMetaType::QString, 24 }, { QMetaType::Bool, 45 },
        }}),
        // Slot 'FeedSecretQueued'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &, bool)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 }, { QMetaType::QString, 24 }, { QMetaType::Bool, 45 },
        }}),
        // Slot 'GetAccessPoints'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QDBusObjectPath &)>(47, 2, QMC::AccessPublic, 0x80000000 | 48, {{
            { 0x80000000 | 23, 3 },
        }}),
        // Slot 'GetActiveConnectionInfo'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(49, 2, QMC::AccessPublic, 0x80000000 | 48),
        // Slot 'GetAutoProxy'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(50, 2, QMC::AccessPublic, 0x80000000 | 48),
        // Slot 'GetProxy'
        QtMocHelpers::SlotData<QDBusPendingReply<QString,QString>(const QString &)>(51, 2, QMC::AccessPublic, 0x80000000 | 52, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'GetProxy'
        QtMocHelpers::SlotData<QDBusReply<QString>(const QString &, QString &)>(51, 2, QMC::AccessPublic, 0x80000000 | 53, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 54, 55 },
        }}),
        // Slot 'GetProxyIgnoreHosts'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(56, 2, QMC::AccessPublic, 0x80000000 | 48),
        // Slot 'GetProxyMethod'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(57, 2, QMC::AccessPublic, 0x80000000 | 48),
        // Slot 'GetSupportedConnectionTypes'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>()>(58, 2, QMC::AccessPublic, 0x80000000 | 59),
        // Slot 'GetWiredConnectionUuid'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QDBusObjectPath &)>(60, 2, QMC::AccessPublic, 0x80000000 | 48, {{
            { 0x80000000 | 23, 3 },
        }}),
        // Slot 'IsDeviceEnabled'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QDBusObjectPath &)>(61, 2, QMC::AccessPublic, 0x80000000 | 62, {{
            { 0x80000000 | 23, 3 },
        }}),
        // Slot 'IsPasswordValid'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &, const QString &)>(63, 2, QMC::AccessPublic, 0x80000000 | 62, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 },
        }}),
        // Slot 'IsWirelessHotspotModeEnabled'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QDBusObjectPath &)>(64, 2, QMC::AccessPublic, 0x80000000 | 62, {{
            { 0x80000000 | 23, 3 },
        }}),
        // Slot 'ListDeviceConnections'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<QDBusObjectPath> >(const QDBusObjectPath &)>(65, 2, QMC::AccessPublic, 0x80000000 | 66, {{
            { 0x80000000 | 23, 3 },
        }}),
        // Slot 'RegisterSecretReceiver'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(67, 2, QMC::AccessPublic, 0x80000000 | 27),
        // Slot 'RegisterSecretReceiverQueued'
        QtMocHelpers::SlotData<void()>(68, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'RequestIPConflictCheck'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &)>(69, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 },
        }}),
        // Slot 'RequestIPConflictCheckQueued'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(70, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 },
        }}),
        // Slot 'RequestWirelessScan'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(71, 2, QMC::AccessPublic, 0x80000000 | 27),
        // Slot 'RequestWirelessScanQueued'
        QtMocHelpers::SlotData<void()>(72, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'SetAutoProxy'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(73, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'SetAutoProxyQueued'
        QtMocHelpers::SlotData<void(const QString &)>(74, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'SetDeviceManaged'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, bool)>(75, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { QMetaType::QString, 3 }, { QMetaType::Bool, 4 },
        }}),
        // Slot 'SetDeviceManagedQueued'
        QtMocHelpers::SlotData<void(const QString &, bool)>(76, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Bool, 4 },
        }}),
        // Slot 'SetProxy'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, const QString &, const QString &)>(77, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 }, { QMetaType::QString, 24 },
        }}),
        // Slot 'SetProxyQueued'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &)>(78, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 }, { QMetaType::QString, 24 },
        }}),
        // Slot 'SetProxyIgnoreHosts'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(79, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'SetProxyIgnoreHostsQueued'
        QtMocHelpers::SlotData<void(const QString &)>(80, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'SetProxyMethod'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(81, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'SetProxyMethodQueued'
        QtMocHelpers::SlotData<void(const QString &)>(82, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'CallQueued'
        QtMocHelpers::SlotData<void(const QString &, const QList<QVariant> &)>(83, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 84 }, { 0x80000000 | 85, 86 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'ActiveConnections'
        QtMocHelpers::PropertyData<QString>(87, QMetaType::QString, QMC::DefaultPropertyFlags, 8),
        // property 'Connections'
        QtMocHelpers::PropertyData<QString>(88, QMetaType::QString, QMC::DefaultPropertyFlags, 9),
        // property 'Connectivity'
        QtMocHelpers::PropertyData<uint>(89, QMetaType::UInt, QMC::DefaultPropertyFlags, 10),
        // property 'Devices'
        QtMocHelpers::PropertyData<QString>(90, QMetaType::QString, QMC::DefaultPropertyFlags, 11),
        // property 'NetworkingEnabled'
        QtMocHelpers::PropertyData<bool>(91, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'State'
        QtMocHelpers::PropertyData<uint>(92, QMetaType::UInt, QMC::DefaultPropertyFlags, 13),
        // property 'VpnEnabled'
        QtMocHelpers::PropertyData<bool>(93, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'WirelessAccessPoints'
        QtMocHelpers::PropertyData<QString>(94, QMetaType::QString, QMC::DefaultPropertyFlags, 15),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NetworkInter, qt_meta_tag_ZN12NetworkInterE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject NetworkInter::staticMetaObject = { {
    QMetaObject::SuperData::link<Dtk::Core::DDBusInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12NetworkInterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12NetworkInterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12NetworkInterE_t>.metaTypes,
    nullptr
} };

void NetworkInter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NetworkInter *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->AccessPointAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->AccessPointPropertiesChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: _t->AccessPointRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->ActiveConnectionInfoChanged(); break;
        case 4: _t->DeviceEnabled((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 5: _t->IPConflict((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 6: _t->NeedSecrets((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->NeedSecretsFinished((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 8: _t->ActiveConnectionsChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->ConnectionsChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->ConnectivityChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 11: _t->DevicesChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->NetworkingEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->StateChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 14: _t->VpnEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->WirelessAccessPointsChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: { QDBusPendingReply<QDBusObjectPath> _r = _t->ActivateAccessPoint((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 17: { QDBusPendingReply<QDBusObjectPath> _r = _t->ActivateConnection((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 18: { QDBusPendingReply<> _r = _t->CancelSecret((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 19: _t->CancelSecretQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 20: { QDBusPendingReply<QDBusObjectPath> _r = _t->CreateConnection((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 21: { QDBusPendingReply<QDBusObjectPath> _r = _t->CreateConnectionForAccessPoint((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 22: { QDBusPendingReply<> _r = _t->DeactivateConnection((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 23: _t->DeactivateConnectionQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 24: { QDBusPendingReply<> _r = _t->DeleteConnection((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 25: _t->DeleteConnectionQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 26: { QDBusPendingReply<> _r = _t->DisableWirelessHotspotMode((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 27: _t->DisableWirelessHotspotModeQueued((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 28: { QDBusPendingReply<> _r = _t->DisconnectDevice((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 29: _t->DisconnectDeviceQueued((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 30: { QDBusPendingReply<QDBusObjectPath> _r = _t->EditConnection((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 31: { QDBusPendingReply<> _r = _t->EnableDevice((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 32: _t->EnableDeviceQueued((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 33: { QDBusPendingReply<> _r = _t->EnableWirelessHotspotMode((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 34: _t->EnableWirelessHotspotModeQueued((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 35: { QDBusPendingReply<> _r = _t->FeedSecret((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 36: _t->FeedSecretQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 37: { QDBusPendingReply<QString> _r = _t->GetAccessPoints((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 38: { QDBusPendingReply<QString> _r = _t->GetActiveConnectionInfo();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 39: { QDBusPendingReply<QString> _r = _t->GetAutoProxy();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 40: { QDBusPendingReply<QString,QString> _r = _t->GetProxy((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString,QString>*>(_a[0]) = std::move(_r); }  break;
        case 41: { QDBusReply<QString> _r = _t->GetProxy((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 42: { QDBusPendingReply<QString> _r = _t->GetProxyIgnoreHosts();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 43: { QDBusPendingReply<QString> _r = _t->GetProxyMethod();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 44: { QDBusPendingReply<QStringList> _r = _t->GetSupportedConnectionTypes();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 45: { QDBusPendingReply<QString> _r = _t->GetWiredConnectionUuid((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 46: { QDBusPendingReply<bool> _r = _t->IsDeviceEnabled((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 47: { QDBusPendingReply<bool> _r = _t->IsPasswordValid((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 48: { QDBusPendingReply<bool> _r = _t->IsWirelessHotspotModeEnabled((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 49: { QDBusPendingReply<QList<QDBusObjectPath>> _r = _t->ListDeviceConnections((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<QDBusObjectPath>>*>(_a[0]) = std::move(_r); }  break;
        case 50: { QDBusPendingReply<> _r = _t->RegisterSecretReceiver();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 51: _t->RegisterSecretReceiverQueued(); break;
        case 52: { QDBusPendingReply<> _r = _t->RequestIPConflictCheck((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 53: _t->RequestIPConflictCheckQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 54: { QDBusPendingReply<> _r = _t->RequestWirelessScan();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 55: _t->RequestWirelessScanQueued(); break;
        case 56: { QDBusPendingReply<> _r = _t->SetAutoProxy((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 57: _t->SetAutoProxyQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 58: { QDBusPendingReply<> _r = _t->SetDeviceManaged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 59: _t->SetDeviceManagedQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 60: { QDBusPendingReply<> _r = _t->SetProxy((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 61: _t->SetProxyQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 62: { QDBusPendingReply<> _r = _t->SetProxyIgnoreHosts((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 63: _t->SetProxyIgnoreHostsQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 64: { QDBusPendingReply<> _r = _t->SetProxyMethod((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 65: _t->SetProxyMethodQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 66: _t->CallQueued((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QVariant>>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 26:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 29:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 31:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 32:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 33:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 34:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 37:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 45:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 46:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 48:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 49:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NetworkInter::*)(const QString & , const QString & )>(_a, &NetworkInter::AccessPointAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkInter::*)(const QString & , const QString & )>(_a, &NetworkInter::AccessPointPropertiesChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkInter::*)(const QString & , const QString & )>(_a, &NetworkInter::AccessPointRemoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkInter::*)()>(_a, &NetworkInter::ActiveConnectionInfoChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkInter::*)(const QString & , bool )>(_a, &NetworkInter::DeviceEnabled, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkInter::*)(const QString & , const QString & )>(_a, &NetworkInter::IPConflict, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkInter::*)(const QString & )>(_a, &NetworkInter::NeedSecrets, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkInter::*)(const QString & , const QString & )>(_a, &NetworkInter::NeedSecretsFinished, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkInter::*)(const QString & ) const>(_a, &NetworkInter::ActiveConnectionsChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkInter::*)(const QString & ) const>(_a, &NetworkInter::ConnectionsChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkInter::*)(uint ) const>(_a, &NetworkInter::ConnectivityChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkInter::*)(const QString & ) const>(_a, &NetworkInter::DevicesChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkInter::*)(bool ) const>(_a, &NetworkInter::NetworkingEnabledChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkInter::*)(uint ) const>(_a, &NetworkInter::StateChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkInter::*)(bool ) const>(_a, &NetworkInter::VpnEnabledChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetworkInter::*)(const QString & ) const>(_a, &NetworkInter::WirelessAccessPointsChanged, 15))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->activeConnections(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->connections(); break;
        case 2: *reinterpret_cast<uint*>(_v) = _t->connectivity(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->devices(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->networkingEnabled(); break;
        case 5: *reinterpret_cast<uint*>(_v) = _t->state(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->vpnEnabled(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->wirelessAccessPoints(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 4: _t->setNetworkingEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setVpnEnabled(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *NetworkInter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NetworkInter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12NetworkInterE_t>.strings))
        return static_cast<void*>(this);
    return Dtk::Core::DDBusInterface::qt_metacast(_clname);
}

int NetworkInter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Dtk::Core::DDBusInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 67)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 67;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 67)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 67;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void NetworkInter::AccessPointAdded(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void NetworkInter::AccessPointPropertiesChanged(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void NetworkInter::AccessPointRemoved(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void NetworkInter::ActiveConnectionInfoChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void NetworkInter::DeviceEnabled(const QString & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void NetworkInter::IPConflict(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void NetworkInter::NeedSecrets(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void NetworkInter::NeedSecretsFinished(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void NetworkInter::ActiveConnectionsChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< NetworkInter *>(this), &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void NetworkInter::ConnectionsChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< NetworkInter *>(this), &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void NetworkInter::ConnectivityChanged(uint _t1)const
{
    QMetaObject::activate<void>(const_cast< NetworkInter *>(this), &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void NetworkInter::DevicesChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< NetworkInter *>(this), &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void NetworkInter::NetworkingEnabledChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< NetworkInter *>(this), &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void NetworkInter::StateChanged(uint _t1)const
{
    QMetaObject::activate<void>(const_cast< NetworkInter *>(this), &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void NetworkInter::VpnEnabledChanged(bool _t1)const
{
    QMetaObject::activate<void>(const_cast< NetworkInter *>(this), &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void NetworkInter::WirelessAccessPointsChanged(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< NetworkInter *>(this), &staticMetaObject, 15, nullptr, _t1);
}
QT_WARNING_POP
