/****************************************************************************
** Meta object code from reading C++ file 'netmanager_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../net-view/operation/private/netmanager_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'netmanager_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3dde7network17NetManagerPrivateE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::NetManagerPrivate::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network17NetManagerPrivateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::NetManagerPrivate",
        "request",
        "",
        "NetManager::CmdType",
        "cmd",
        "id",
        "QVariantMap",
        "param",
        "vpnStatusChanged",
        "exec",
        "onItemAdded",
        "parentID",
        "NetItemPrivate*",
        "item",
        "onItemRemoved",
        "onDataChanged",
        "dataType",
        "QVariant",
        "value",
        "sendRequest",
        "onRequestPassword",
        "dev",
        "findPasswordRequestItem",
        "clearPasswordRequest",
        "retranslateUi",
        "onItemDestroyed",
        "obj"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'request'
        QtMocHelpers::SignalData<void(NetManager::CmdType, const QString &, const QVariantMap &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Signal 'vpnStatusChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'exec'
        QtMocHelpers::SlotData<void(NetManager::CmdType, const QString &, const QVariantMap &)>(9, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'onItemAdded'
        QtMocHelpers::SlotData<void(const QString &, NetItemPrivate *)>(10, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 11 }, { 0x80000000 | 12, 13 },
        }}),
        // Slot 'onItemRemoved'
        QtMocHelpers::SlotData<void(const QString &)>(14, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'onDataChanged'
        QtMocHelpers::SlotData<void(int, const QString &, const QVariant &)>(15, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 16 }, { QMetaType::QString, 5 }, { 0x80000000 | 17, 18 },
        }}),
        // Slot 'sendRequest'
        QtMocHelpers::SlotData<void(NetManager::CmdType, const QString &, const QVariantMap &)>(19, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'sendRequest'
        QtMocHelpers::SlotData<void(NetManager::CmdType, const QString &)>(19, 2, QMC::AccessProtected | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 },
        }}),
        // Slot 'onRequestPassword'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QVariantMap &)>(20, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 21 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'findPasswordRequestItem'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'clearPasswordRequest'
        QtMocHelpers::SlotData<void(const QString &)>(23, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'retranslateUi'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onItemDestroyed'
        QtMocHelpers::SlotData<void(QObject *)>(25, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QObjectStar, 26 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NetManagerPrivate, qt_meta_tag_ZN3dde7network17NetManagerPrivateE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::NetManagerPrivate::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network17NetManagerPrivateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network17NetManagerPrivateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network17NetManagerPrivateE_t>.metaTypes,
    nullptr
} };

void dde::network::NetManagerPrivate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NetManagerPrivate *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->request((*reinterpret_cast<std::add_pointer_t<NetManager::CmdType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[3]))); break;
        case 1: _t->vpnStatusChanged(); break;
        case 2: _t->exec((*reinterpret_cast<std::add_pointer_t<NetManager::CmdType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[3]))); break;
        case 3: _t->onItemAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<NetItemPrivate*>>(_a[2]))); break;
        case 4: _t->onItemRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->onDataChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3]))); break;
        case 6: _t->sendRequest((*reinterpret_cast<std::add_pointer_t<NetManager::CmdType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[3]))); break;
        case 7: _t->sendRequest((*reinterpret_cast<std::add_pointer_t<NetManager::CmdType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 8: _t->onRequestPassword((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[3]))); break;
        case 9: _t->findPasswordRequestItem(); break;
        case 10: _t->clearPasswordRequest((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->retranslateUi(); break;
        case 12: _t->onItemDestroyed((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NetManagerPrivate::*)(NetManager::CmdType , const QString & , const QVariantMap & )>(_a, &NetManagerPrivate::request, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NetManagerPrivate::*)()>(_a, &NetManagerPrivate::vpnStatusChanged, 1))
            return;
    }
}

const QMetaObject *dde::network::NetManagerPrivate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::NetManagerPrivate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network17NetManagerPrivateE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dde::network::NetManagerPrivate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void dde::network::NetManagerPrivate::request(NetManager::CmdType _t1, const QString & _t2, const QVariantMap & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void dde::network::NetManagerPrivate::vpnStatusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
