/****************************************************************************
** Meta object code from reading C++ file 'dccnetwork.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../operation/dccnetwork.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dccnetwork.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3dde7network10DccNetworkE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::DccNetwork::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network10DccNetworkE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::DccNetwork",
        "request",
        "",
        "NetManager::CmdType",
        "cmd",
        "id",
        "QVariantMap",
        "param",
        "managerChanged",
        "NetManager*",
        "manager",
        "rootChanged",
        "exec",
        "setClipboard",
        "text",
        "toMap",
        "QMap<QString,QString>",
        "map",
        "toStringMap",
        "init",
        "CheckPasswordValid",
        "key",
        "password",
        "root",
        "NetItem*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'request'
        QtMocHelpers::SignalData<void(NetManager::CmdType, const QString &, const QVariantMap &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Signal 'managerChanged'
        QtMocHelpers::SignalData<void(NetManager *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'rootChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'exec'
        QtMocHelpers::SlotData<void(NetManager::CmdType, const QString &, const QVariantMap &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Slot 'exec'
        QtMocHelpers::SlotData<void(NetManager::CmdType, const QString &)>(12, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 5 },
        }}),
        // Slot 'setClipboard'
        QtMocHelpers::SlotData<void(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'toMap'
        QtMocHelpers::SlotData<QVariantMap(QMap<QString,QString>)>(15, 2, QMC::AccessPublic, 0x80000000 | 6, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'toStringMap'
        QtMocHelpers::SlotData<QMap<QString,QString>(QVariantMap)>(18, 2, QMC::AccessPublic, 0x80000000 | 16, {{
            { 0x80000000 | 6, 17 },
        }}),
        // Slot 'init'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessProtected, QMetaType::Void),
        // Method 'CheckPasswordValid'
        QtMocHelpers::MethodData<bool(const QString &, const QString &)>(20, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 21 }, { QMetaType::QString, 22 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'manager'
        QtMocHelpers::PropertyData<NetManager*>(10, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'root'
        QtMocHelpers::PropertyData<NetItem*>(23, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DccNetwork, qt_meta_tag_ZN3dde7network10DccNetworkE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::DccNetwork::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network10DccNetworkE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network10DccNetworkE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network10DccNetworkE_t>.metaTypes,
    nullptr
} };

void dde::network::DccNetwork::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DccNetwork *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->request((*reinterpret_cast<std::add_pointer_t<NetManager::CmdType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[3]))); break;
        case 1: _t->managerChanged((*reinterpret_cast<std::add_pointer_t<NetManager*>>(_a[1]))); break;
        case 2: _t->rootChanged(); break;
        case 3: _t->exec((*reinterpret_cast<std::add_pointer_t<NetManager::CmdType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[3]))); break;
        case 4: _t->exec((*reinterpret_cast<std::add_pointer_t<NetManager::CmdType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: _t->setClipboard((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: { QVariantMap _r = _t->toMap((*reinterpret_cast<std::add_pointer_t<QMap<QString,QString>>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 7: { QMap<QString,QString> _r = _t->toStringMap((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QMap<QString,QString>*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->init(); break;
        case 9: { bool _r = _t->CheckPasswordValid((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< NetManager* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DccNetwork::*)(NetManager::CmdType , const QString & , const QVariantMap & )>(_a, &DccNetwork::request, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccNetwork::*)(NetManager * )>(_a, &DccNetwork::managerChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DccNetwork::*)()>(_a, &DccNetwork::rootChanged, 2))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetItem* >(); break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< NetManager* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<NetManager**>(_v) = _t->manager(); break;
        case 1: *reinterpret_cast<NetItem**>(_v) = _t->root(); break;
        default: break;
        }
    }
}

const QMetaObject *dde::network::DccNetwork::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::DccNetwork::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network10DccNetworkE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dde::network::DccNetwork::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void dde::network::DccNetwork::request(NetManager::CmdType _t1, const QString & _t2, const QVariantMap & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void dde::network::DccNetwork::managerChanged(NetManager * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void dde::network::DccNetwork::rootChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
