/****************************************************************************
** Meta object code from reading C++ file 'proxycontroller.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../proxycontroller.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'proxycontroller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3dde7network15ProxyControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto dde::network::ProxyController::qt_create_metaobjectdata<qt_meta_tag_ZN3dde7network15ProxyControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dde::network::ProxyController",
        "autoProxyChanged",
        "",
        "proxyChanged",
        "SysProxyConfig",
        "proxyAuthChanged",
        "proxyMethodChanged",
        "ProxyMethod",
        "proxyIgnoreHostsChanged",
        "systemProxyExistChanged",
        "isExit",
        "appEnableChanged",
        "enabled",
        "appIPChanged",
        "ip",
        "appPasswordChanged",
        "password",
        "appTypeChanged",
        "AppProxyType",
        "type",
        "appUsernameChanged",
        "username",
        "appPortChanged",
        "port",
        "onIPChanged",
        "value",
        "onPasswordChanged",
        "onTypeChanged",
        "onUserChanged",
        "onPortChanged",
        "onProxyMethodChanged",
        "method"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'autoProxyChanged'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'proxyChanged'
        QtMocHelpers::SignalData<void(const SysProxyConfig &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Signal 'proxyAuthChanged'
        QtMocHelpers::SignalData<void(const SysProxyConfig &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Signal 'proxyMethodChanged'
        QtMocHelpers::SignalData<void(const ProxyMethod &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Signal 'proxyIgnoreHostsChanged'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'systemProxyExistChanged'
        QtMocHelpers::SignalData<void(bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 10 },
        }}),
        // Signal 'appEnableChanged'
        QtMocHelpers::SignalData<void(bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 12 },
        }}),
        // Signal 'appIPChanged'
        QtMocHelpers::SignalData<void(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Signal 'appPasswordChanged'
        QtMocHelpers::SignalData<void(const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Signal 'appTypeChanged'
        QtMocHelpers::SignalData<void(const AppProxyType &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Signal 'appUsernameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
        // Signal 'appPortChanged'
        QtMocHelpers::SignalData<void(const uint &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 23 },
        }}),
        // Slot 'onIPChanged'
        QtMocHelpers::SlotData<void(const QString &)>(24, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'onPasswordChanged'
        QtMocHelpers::SlotData<void(const QString &)>(26, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'onTypeChanged'
        QtMocHelpers::SlotData<void(const QString &)>(27, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'onUserChanged'
        QtMocHelpers::SlotData<void(const QString &)>(28, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'onPortChanged'
        QtMocHelpers::SlotData<void(uint)>(29, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::UInt, 25 },
        }}),
        // Slot 'onProxyMethodChanged'
        QtMocHelpers::SlotData<void(const QString &)>(30, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 31 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ProxyController, qt_meta_tag_ZN3dde7network15ProxyControllerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dde::network::ProxyController::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network15ProxyControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network15ProxyControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dde7network15ProxyControllerE_t>.metaTypes,
    nullptr
} };

void dde::network::ProxyController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ProxyController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->autoProxyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->proxyChanged((*reinterpret_cast<std::add_pointer_t<SysProxyConfig>>(_a[1]))); break;
        case 2: _t->proxyAuthChanged((*reinterpret_cast<std::add_pointer_t<SysProxyConfig>>(_a[1]))); break;
        case 3: _t->proxyMethodChanged((*reinterpret_cast<std::add_pointer_t<ProxyMethod>>(_a[1]))); break;
        case 4: _t->proxyIgnoreHostsChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->systemProxyExistChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->appEnableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->appIPChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->appPasswordChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->appTypeChanged((*reinterpret_cast<std::add_pointer_t<AppProxyType>>(_a[1]))); break;
        case 10: _t->appUsernameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->appPortChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 12: _t->onIPChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->onPasswordChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->onTypeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->onUserChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->onPortChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 17: _t->onProxyMethodChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ProxyController::*)(const QString & )>(_a, &ProxyController::autoProxyChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProxyController::*)(const SysProxyConfig & )>(_a, &ProxyController::proxyChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProxyController::*)(const SysProxyConfig & )>(_a, &ProxyController::proxyAuthChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProxyController::*)(const ProxyMethod & )>(_a, &ProxyController::proxyMethodChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProxyController::*)(const QString & )>(_a, &ProxyController::proxyIgnoreHostsChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProxyController::*)(bool )>(_a, &ProxyController::systemProxyExistChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProxyController::*)(bool )>(_a, &ProxyController::appEnableChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProxyController::*)(const QString & )>(_a, &ProxyController::appIPChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProxyController::*)(const QString & )>(_a, &ProxyController::appPasswordChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProxyController::*)(const AppProxyType & )>(_a, &ProxyController::appTypeChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProxyController::*)(const QString & )>(_a, &ProxyController::appUsernameChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProxyController::*)(const uint & )>(_a, &ProxyController::appPortChanged, 11))
            return;
    }
}

const QMetaObject *dde::network::ProxyController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dde::network::ProxyController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dde7network15ProxyControllerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dde::network::ProxyController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void dde::network::ProxyController::autoProxyChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void dde::network::ProxyController::proxyChanged(const SysProxyConfig & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void dde::network::ProxyController::proxyAuthChanged(const SysProxyConfig & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void dde::network::ProxyController::proxyMethodChanged(const ProxyMethod & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void dde::network::ProxyController::proxyIgnoreHostsChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void dde::network::ProxyController::systemProxyExistChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void dde::network::ProxyController::appEnableChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void dde::network::ProxyController::appIPChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void dde::network::ProxyController::appPasswordChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void dde::network::ProxyController::appTypeChanged(const AppProxyType & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void dde::network::ProxyController::appUsernameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void dde::network::ProxyController::appPortChanged(const uint & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}
QT_WARNING_POP
